/**
 * @license
 *-------------------------------------------------------------------------------------------
 * Copyright © 2025 Progress Software Corporation. All rights reserved.
 * Licensed under commercial license. See LICENSE.md in the package root for more information
 *-------------------------------------------------------------------------------------------
 */
import { BaseEvent } from '@progress/kendo-react-common';
import { CustomComponent } from '@progress/kendo-react-common';
import { default as default_2 } from 'prop-types';
import { DraggableDragEvent } from '@progress/kendo-react-common';
import { FormComponent } from '@progress/kendo-react-common';
import { FormComponentProps } from '@progress/kendo-react-common';
import { FormComponentValidity } from '@progress/kendo-react-common';
import { HTMLAttributes } from 'react';
import { IconHandle } from '@progress/kendo-react-common';
import { IconProps } from '@progress/kendo-react-common';
import { InputsClassStructure } from '@progress/kendo-react-common';
import { JSX } from 'react/jsx-runtime';
import { NumberFormatOptions } from '@progress/kendo-react-intl';
import { PopupAnimation } from '@progress/kendo-react-popup';
import * as React_2 from 'react';
import { SVGIcon } from '@progress/kendo-react-common';
import { SvgIconHandle } from '@progress/kendo-react-common';
import { SvgIconProps } from '@progress/kendo-react-common';

/**
 * Represents the [KendoReact Checkbox component]({% slug overview_checkbox %}).
 *
 * @example
 * ```jsx
 * const App = () => {
 *      return <Checkbox />;
 * }
 * const root = ReactDOM.createRoot(document.getElementById('app'));
 * ```
 */
export declare const Checkbox: React_2.ForwardRefExoticComponent<CheckboxProps & React_2.RefAttributes<CheckboxHandle | null>>;

/**
 * The arguments for the `onBlur` Checkbox event.
 */
export declare interface CheckboxBlurEvent extends BaseEvent<CheckboxHandle> {
}

/**
 * The arguments for the `onChange` Checkbox event.
 */
export declare interface CheckboxChangeEvent extends BaseEvent<CheckboxHandle> {
    /**
     * The new value of the Checkbox.
     */
    value: boolean;
}

/**
 * The arguments for the `onFocus` Checkbox event.
 */
export declare interface CheckboxFocusEvent extends BaseEvent<CheckboxHandle> {
}

/**
 * The Checkbox ref.
 */
export declare interface CheckboxHandle {
    element: HTMLInputElement | null;
    focus: any;
    value?: string | number | string[] | boolean | null;
    name?: string | null;
}

/**
 * Represents the props of the [KendoReact Checkbox component]({% slug overview_checkbox %}).
 * Extends the [native input props](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement).
 */
export declare interface CheckboxProps extends ToggleBaseProps, FormComponentProps, Omit_3<React.InputHTMLAttributes<HTMLInputElement>, 'checked' | 'value' | 'size' | 'onChange' | 'onFocus' | 'onBlur'> {
    /**
     * Sets the checked state of the Checkbox.
     * Set to null to enable the indeterminate state of the Checkbox ([see example]({% slug overview_checkbox %})).
     *
     * @example
     * ```jsx
     * <Checkbox checked={true} />
     * ```
     */
    checked?: boolean | null;
    /**
     * If the type is different than boolean and the `checked` property is provided it's passed to the underlying `input` element.
     * If set to boolean and the `checked` property is omitted sets the checked state of the Checkbox.
     * Set null to enable the indeterminate state of the Checkbox ([see example]({% slug overview_checkbox %})).
     */
    value?: string | number | string[] | boolean | null;
    /**
     * Sets the `className` of the wrapping element of the Checkbox.
     */
    className?: string;
    /**
     * Sets the `className` of the label element of the Checkbox.
     */
    labelClassName?: string;
    /**
     * The React elements that are passed as children to the rendered component.
     */
    children?: any;
    /**
     * Sets the default value of checked attribute when used in uncontrolled mode ([see example]({% slug default_state %})).
     */
    defaultChecked?: boolean;
    /**
     * The default value of the Checkbox.
     */
    defaultValue?: any;
    /**
     * Represents the `dir` HTML attribute. This is used to switch from LTR to RTL.
     */
    dir?: string;
    /**
     * Sets the disabled state of the Checkbox
     * ([see example]({% slug disabled_checkbox %})).
     */
    disabled?: boolean;
    /**
     * Sets the `id` of the Checkbox.
     */
    id?: string;
    /**
     * Configures the `size` of the Checkbox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `rounded` style of the Checkbox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a rounded `className`.
     *
     * @default `medium`
     */
    rounded?: null | 'small' | 'medium' | 'large';
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Sets the label of the Checkbox component ([see example]({% slug labels_checkbox %})).
     *
     * @example
     * ```jsx
     * <Checkbox label="Accept Terms" />
     * ```
     */
    label?: React.ReactNode;
    /**
     * Sets the label position of the Checkbox component ([see example]({% slug labels_checkbox %})).
     *
     * @example
     * ```jsx
     * <Checkbox labelPlacement="before" />
     * ```
     */
    labelPlacement?: 'before' | 'after';
    /**
     * Sets the optional text after the label of the Checkbox component.
     */
    labelOptional?: boolean;
    /**
     * Sets the `tabIndex` property of the Checkbox.
     * Defaults to `0`.
     */
    tabIndex?: number;
    /**
     * Represents the `autoFocus` HTML attribute that will be applied to the input element of the Checkbox. (Defaults to `false`)
     */
    autoFocus?: boolean;
    /**
     * The event handler that will be fired when the user edits the value.
     */
    onChange?: (event: CheckboxChangeEvent) => void;
    /**
     * The event handler that will be fired when Checkbox is focused.
     */
    onFocus?: (event: CheckboxFocusEvent) => void;
    /**
     * The event handler that will be fired when Checkbox is blurred.
     */
    onBlur?: (event: CheckboxBlurEvent) => void;
}

/**
 * Represents the PropsContext of the `Checkbox` component.
 * Used for global configuration of all `Checkbox` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const CheckboxPropsContext: React_2.Context<(p: CheckboxProps) => CheckboxProps>;

/** @hidden */
export declare type ColorGradient = ColorGradientHandle;

/**
 * Represents the [KendoReact ColorGradient component]({% slug overview_colorgradient %}).
 *
 * Accepts properties of type [ColorGradientProps]({% slug api_inputs_colorgradientprops %}).
 * Obtaining the `ref` returns an object of type [ColorGradientHandle]({% slug api_inputs_colorgradienthandle %}).
 *
 * @example
 * ```jsx
 * class App extends React.Component {
 *     render() {
 *         return <ColorGradient />;
 *     }
 * }
 * ReactDOM.render(<App />, document.querySelector('my-app'));
 * ```
 */
export declare const ColorGradient: React_2.ForwardRefExoticComponent<ColorGradientProps & React_2.RefAttributes<any>>;

/**
 * The arguments for the `onChange` ColorGradient event.
 */
export declare interface ColorGradientChangeEvent extends BaseEvent<ColorGradient> {
    /**
     * The current value of the ColorGradient.
     */
    value: string;
}

/**
 * Represent the `ref` of the ColorGradient component.
 */
export declare interface ColorGradientHandle extends Pick<ColorGradientWithoutContext, keyof ColorGradientWithoutContext> {
}

/**
 * Represents the props of the [KendoReact ColorGradient component]({% slug overview_colorgradient %}).
 */
export declare interface ColorGradientProps {
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Represents the label of the `hsv` drag handle component used inside the ColorGradient.
     */
    ariaLabelHSV?: string;
    /**
     * Represent the label of the component.
     */
    ariaLabel?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Represents the text rendered inside the `hsv` drag handle.
     */
    ariaValueText?: string;
    /**
     * Enables the color contrast tool.
     * Sets the background color that will be compared to the selected value.
     * The tool will calculate the contrast ratio between two colors.
     * Currently, only the RGBA format is supported.
     *
     * @example
     * ```jsx
     * <ColorGradient backgroundColor="#ffffff" />
     * ```
     */
    backgroundColor?: string;
    /**
     * Sets additional classes to the ColorGradient.
     */
    className?: string;
    /**
     * The default value of the ColorGradient.
     */
    defaultValue?: string;
    /**
     * Determines whether the ColorGradient is disabled
     * ([more information and example]({% slug disabled_colorgradient %})).
     *
     * @example
     * ```jsx
     * class App extends React.Component {
     *    render() {
     *       return (
     *           <ColorGradient disabled={true} />
     *       );
     *    }
     * }
     * ReactDOM.render(<App />, document.querySelector('my-app'));
     * ```
     */
    disabled?: boolean;
    /**
     * Sets the default input format in the gradient input editor.
     *
     * @default 'rgb'
     *
     * @example
     * ```jsx
     * <ColorGradient format="hex" />
     * ```
     */
    format?: 'rgba' | 'rgb' | 'hex';
    /**
     * Determines the step (in pixels) when moving the gradient drag handle using
     * the keyboard arrow keys while holding the shift key.
     *
     * @default 2
     */
    gradientSliderSmallStep?: number;
    /**
     * Determines the step (in pixels) when moving the gradient drag handle
     * using the keyboard arrow keys.
     *
     * @default 5
     */
    gradientSliderStep?: number;
    /**
     * Specifies the id of the component.
     */
    id?: string;
    /**
     * @hidden
     */
    isInsidePopup?: boolean;
    /**
     * Determines whether the alpha slider and the alpha input will be displayed. Defaults to `true`.
     *
     * @example
     * ```jsx
     * <ColorGradient opacity={false} />
     * ```
     */
    opacity?: boolean;
    /**
     * @hidden
     */
    role?: string;
    /**
     * The styles that are applied to the ColorGradient.
     */
    style?: React.CSSProperties;
    /**
     * Sets the `tabIndex` property of the ColorGradient.
     */
    tabIndex?: number;
    /**
     * The value of the ColorGradient.
     */
    value?: string;
    /**
     * Determines the event handler that will be fired when the user edits the value.
     */
    onChange?: (event: ColorGradientChangeEvent) => void;
    /**
     * Represents the focus event.
     */
    onFocus?: (event: any) => void;
    /**
     * Configures the `size` of the ColorGradient.
     *
     * The available options are:
     * - `small`
     * - `medium`
     * - `large`
     * - `null`&mdash;This option removes the the built-in size styles of the ColorGradient. Allows for custom `padding`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * @hidden
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * @hidden
     */
    _adaptive?: boolean;
}

/**
 * Represents the PropsContext of the `ColorGradient` component.
 * Used for global configuration of all `ColorGradient` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const ColorGradientPropsContext: React_2.Context<(p: ColorGradientProps) => ColorGradientProps>;

/**
 * @hidden
 */
export declare interface ColorGradientState {
    hsva: HSVA;
    backgroundColor: string;
    rgba: RGBA;
    hex: string;
    isFirstRender: boolean;
    guid: string;
}

/** @hidden */
export declare class ColorGradientWithoutContext extends React_2.Component<ColorGradientProps, ColorGradientState> {
    static displayName: string;
    /**
     * @hidden
     */
    static propTypes: {
        defaultValue: default_2.Requireable<string>;
        value: default_2.Requireable<string>;
        onChange: default_2.Requireable<(...args: any[]) => any>;
        onFocus: default_2.Requireable<(...args: any[]) => any>;
        opacity: default_2.Requireable<boolean>;
        backgroundColor: default_2.Requireable<string>;
        format: default_2.Requireable<any>;
        disabled: default_2.Requireable<boolean>;
        style: default_2.Requireable<any>;
        id: default_2.Requireable<string>;
        role: default_2.Requireable<string>;
        ariaLabel: default_2.Requireable<string>;
        ariaLabelledBy: default_2.Requireable<string>;
        ariaDescribedBy: default_2.Requireable<string>;
        className: default_2.Requireable<string>;
        size: default_2.Requireable<string | null>;
    };
    /**
     * @hidden
     */
    static defaultProps: {
        opacity: boolean;
        role: string;
        format: "hex" | "rgba" | "rgb";
        size: string;
    };
    /**
     * @hidden
     */
    wrapperRef: React_2.RefObject<HTMLDivElement | null>;
    /**
     * @hidden
     */
    hsvGradientRef: React_2.RefObject<HTMLDivElement | null>;
    private gradientWrapper;
    private alphaSlider;
    private navigation?;
    private hsvNavigation?;
    private readonly showLicenseWatermark;
    private resizeObserver;
    constructor(props: ColorGradientProps);
    /**
     * @hidden
     */
    static getDerivedStateFromProps(props: ColorGradientProps, state: ColorGradientState): {
        hsva: any;
        backgroundColor: string;
        rgba: any;
        hex: any;
    } | null;
    /**
     * @hidden
     */
    componentDidMount(): void;
    /**
     * @hidden
     */
    componentWillUnmount(): void;
    /**
     * @hidden
     */
    componentDidUpdate(_: ColorGradientProps, prevState: ColorGradientState): void;
    /**
     * @hidden
     */
    focus: () => void;
    /**
     * @hidden
     */
    onHexChange: (hex: string, value: string, event: any) => void;
    /**
     * @hidden
     */
    onRgbaChange: (rgba: RGBA, event: NumericTextBoxChangeEvent) => void;
    /**
     * @hidden
     */
    onAlphaSliderChange: (event: SliderChangeEvent) => void;
    /**
     * @hidden
     */
    onHueSliderChange: (event: SliderChangeEvent) => void;
    /**
     * @hidden
     */
    onDrag: (e: DraggableDragEvent) => void;
    /**
     * @hidden
     */
    onRelease: () => void;
    /**
     * @hidden
     */
    onGradientWrapperClick: (event: React_2.MouseEvent<HTMLDivElement>) => void;
    /**
     * @hidden
     */
    onHsvGradientKeyDown: (event: React_2.KeyboardEvent<HTMLDivElement>) => void;
    /**
     * @hidden
     */
    onHsvGradientValueChange: (element: HTMLElement, moveX: number, moveY: number) => void;
    /**
     * @hidden
     */
    renderRectangleDragHandle(): JSX.Element;
    /**
     * @hidden
     */
    changePosition: (event: any) => void;
    /**
     * @hidden
     */
    moveDragHandle(positionX: number, positionY: number): void;
    /**
     * @hidden
     */
    handleHsvaChange(hsva: HSVA, syntheticEvent: React_2.SyntheticEvent<any>, nativeEvent: any): void;
    /**
     * @hidden
     */
    dispatchChangeEvent(value: string, syntheticEvent: React_2.SyntheticEvent<any>, nativeEvent: any): void;
    /**
     * @hidden
     */
    onFocus: (nativeEvent: any) => void;
    /**
     * @hidden
     */
    static getStateFromValue(value: string, componentGuid?: string): {
        hsva: any;
        backgroundColor: string;
        rgba: any;
        hex: any;
    };
    /**
     * @hidden
     */
    setAlphaSliderBackground(backgroundColor: string): void;
    /**
     * @hidden
     */
    get isUncontrolled(): boolean;
    /**
     * @hidden
     */
    getGradientRectMetrics(): DOMRect;
    /**
     * @hidden
     */
    render(): JSX.Element;
    private onKeyDown;
}

/**
 * @hidden
 */
export declare class ColorInput extends React_2.Component<ColorInputProps, {
    inputMode: string;
}> {
    constructor(props: ColorInputProps);
    render(): JSX.Element;
    private onRgbaRChange;
    private onRgbaGChange;
    private onRgbaBChange;
    private onRgbaAChange;
    private dispatchRgbaChange;
    private onToggleModeChange;
}

/**
 * @hidden
 */
declare interface ColorInputProps {
    rgba: RGBA;
    onRgbaChange: (rgba: RGBA, event: NumericTextBoxChangeEvent) => void;
    hex: string;
    onHexChange: any;
    opacity: boolean;
    disabled?: boolean;
    defaultInputMode?: 'rgba' | 'rgb' | 'hex';
    size?: 'small' | 'medium' | 'large' | null;
    fillMode?: 'solid' | 'outline' | 'flat' | null;
}

/** @hidden */
export declare type ColorPalette = ColorPaletteHandle;

/**
 * Represents the [KendoReact ColorPalette component]({% slug overview_colorpalette %}).
 *
 * Accepts properties of type [ColorPaletteProps]({% slug api_inputs_colorpaletteprops %}).
 * Obtaining the `ref` returns an object of type [ColorPaletteHandle]({% slug api_inputs_colorpalettehandle %}).
 *
 * ```jsx
 * class App extends React.Component {
 *     render() {
 *         return <ColorPalette palette='basic' />;
 *     }
 * }
 * ReactDOM.render(<App />, document.querySelector('my-app'));
 * ```
 */
export declare const ColorPalette: React_2.ForwardRefExoticComponent<ColorPaletteProps & React_2.RefAttributes<any>>;

/**
 * The arguments for the `onChange` ColorPalette event.
 */
export declare interface ColorPaletteChangeEvent extends BaseEvent<ColorPalette> {
    /**
     * The current value of the ColorPalette.
     */
    value: string;
    /**
     * The current value of the ColorPalette in RGBA format.
     */
    rgbaValue: string;
}

/**
 * Represent the `ref` of the ColorPalette component.
 */
export declare interface ColorPaletteHandle extends Pick<ColorPaletteWithoutContext, keyof ColorPaletteWithoutContext> {
}

/**
 * Represents the props of the [KendoReact ColorPalette component]({% slug overview_colorpalette %}).
 */
export declare interface ColorPaletteProps {
    /**
     * The color palette that will be displayed.
     *
     * The supported values are:
     * * The name of the predefined palette preset (for example, `office`, `basic`, and `apex`).
     * * A string array.
     *
     * @example
     * ```jsx
     * <ColorPalette palette={['#ff0000', '#00ff00', '#0000ff']} />
     * ```
     */
    palette?: string[] | string;
    /**
     * Specifies the number of columns that will be displayed.
     * Defaults to `10`.
     *
     * @example
     * ```jsx
     * <ColorPalette columns={5} />
     * ```
     */
    columns?: number;
    /**
     * Specifies the size of a color cell in px.
     * Defaults to `24`.
     *
     * @example
     * ```jsx
     * <ColorPalette tileSize={30} />
     * ```
     */
    tileSize?: number | TileSize;
    /**
     * The default value of the ColorPalette.
     */
    defaultValue?: string;
    /**
     * The value of the ColorPalette.
     */
    value?: string;
    /**
     * Determines whether the ColorPalette is disabled
     * ([more information and example]({% slug disabled_colorpalette %})).
     *
     * @example
     * ```jsx
     * class App extends React.Component {
     *    render() {
     *       return (
     *           <ColorPalette disabled={true} />
     *       );
     *    }
     * }
     * ReactDOM.render(<App />, document.querySelector('my-app'));
     * ```
     */
    disabled?: boolean;
    /**
     * Sets the `tabIndex` property of the ColorPalette.
     */
    tabIndex?: number;
    /**
     * Specifies the id of the component.
     */
    id?: string;
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * @hidden
     */
    ariaDisabled?: boolean;
    /**
     * Determines the event handler that will be fired when the user edits the value.
     */
    onChange?: (event: ColorPaletteChangeEvent) => void;
    /**
     * Represent the focus event of the ColorPalette.
     */
    onFocus?: (event: FocusEvent) => void;
    /**
     * Sets additional classes to the ColorPalette.
     */
    className?: string;
    /**
     * Configures the `size` of the ColorPalette.
     *
     * The available options are:
     * - `small`
     * - `medium`
     * - `large`
     * - `null`&mdash;This option removes the the built-in size styles of the ColorPalette. Allows for custom `padding`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
}

/**
 * Represents the PropsContext of the `ColorPalette` component.
 * Used for global configuration of all `ColorPalette` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const ColorPalettePropsContext: React_2.Context<(p: ColorPaletteProps) => ColorPaletteProps>;

/**
 * @hidden
 */
export declare interface ColorPaletteState {
    selectedColor?: string;
    focusedColor?: string;
    isFirstRender: boolean;
}

/** @hidden */
export declare class ColorPaletteWithoutContext extends React_2.Component<ColorPaletteProps, ColorPaletteState> {
    static displayName: string;
    /**
     * @hidden
     */
    static propTypes: {
        palette: default_2.Requireable<NonNullable<string | string[] | null | undefined>>;
        columns: default_2.Requireable<number>;
        tileSize: default_2.Requireable<any>;
        defaultValue: default_2.Requireable<string>;
        value: default_2.Requireable<string>;
        disabled: default_2.Requireable<boolean>;
        tabIndex: default_2.Requireable<number>;
        onChange: default_2.Requireable<(...args: any[]) => any>;
        onFocus: default_2.Requireable<(...args: any[]) => any>;
        id: default_2.Requireable<string>;
        ariaLabelledBy: default_2.Requireable<string>;
        ariaDescribedBy: default_2.Requireable<string>;
        className: default_2.Requireable<string>;
        size: default_2.Requireable<string | null>;
    };
    /**
     * @hidden
     */
    static defaultProps: {
        palette: string;
        tileSize: number;
        size: string;
    };
    /**
     * @hidden
     */
    wrapperRef: React_2.RefObject<HTMLDivElement | null>;
    private paletteService;
    private get guid();
    constructor(props: ColorPaletteProps);
    /**
     * @hidden
     */
    focus: () => void;
    /**
     * @hidden
     */
    render(): "" | JSX.Element;
    /**
     * @hidden
     */
    static getDerivedStateFromProps(props: ColorPaletteProps, state: ColorPaletteState): {
        selectedColor: undefined;
        isFirstRender?: undefined;
    } | {
        selectedColor: string;
        isFirstRender?: undefined;
    } | {
        isFirstRender: boolean;
        selectedColor?: undefined;
    } | null;
    private onKeyDown;
    private onColorClick;
    private onFocus;
    private onBlur;
    private handleCellNavigation;
    private handleEnter;
    private dispatchChangeEvent;
    private get focusedColorCooridanates();
    private get isUncontrolled();
    private getPaletteInfo;
    private renderRows;
    private renderColumns;
    private createCellId;
}

/**
 * Represents the [KendoReact ColorPicker component]({% slug overview_colorpicker %}).
 *
 * @example
 * ```jsx
 * class App extends React.Component {
 *     render() {
 *         return <ColorPicker />;
 *     }
 * }
 * ReactDOM.render(<App />, document.querySelector('my-app'));
 * ```
 */
export declare const ColorPicker: React_2.ForwardRefExoticComponent<ColorPickerProps & React_2.RefAttributes<ColorPickerHandle | null>>;

/**
 * The arguments for the `onActiveColorClick` ColorPicker event.
 */
declare interface ColorPickerActiveColorClick {
    /**
     * The current value of the ColorPicker.
     */
    value: string;
    /**
     * A React Synthetic Event.
     */
    syntheticEvent: React.SyntheticEvent<any>;
    /**
     * A native DOM event.
     */
    nativeEvent: any;
    /**
     * The event target.
     */
    target: ColorPickerHandle;
}

/**
 * The arguments for the `onBlur` ColorPicker event.
 */
export declare interface ColorPickerBlurEvent {
    /**
     * A React Synthetic Event.
     */
    syntheticEvent: React.SyntheticEvent<any>;
    /**
     * A native DOM event.
     */
    nativeEvent: any;
}

/**
 * The arguments for the `onChange` ColorPicker event.
 */
export declare interface ColorPickerChangeEvent {
    /**
     * The current value of the ColorPicker.
     */
    value: string;
    /**
     * A React Synthetic Event.
     */
    syntheticEvent: React.SyntheticEvent<any>;
    /**
     * A native DOM event.
     */
    nativeEvent: any;
    /**
     * The event target.
     */
    target: ColorPickerHandle;
}

/**
 * The arguments for the `onFocus` ColorPicker event.
 */
export declare interface ColorPickerFocusEvent {
    /**
     * A React Synthetic Event.
     */
    syntheticEvent: React.SyntheticEvent<any>;
    /**
     * A native DOM event.
     */
    nativeEvent: any;
}

/**
 * The settings of the ColorGradient that is nested inside the popup of the ColorPicker
 * ([see example]({% slug customizecolorpicker_colorpicker %}#toc-customizing-the-gradient-popup)).
 */
export declare interface ColorPickerGradientSettings {
    /**
     * Specifies if the component will render an alpha slider.
     * Defaults to `true`.
     */
    opacity?: boolean;
    /**
     * Enables the color contrast tool.
     * Sets the background color that will be compared to the selected value.
     * The tool will calculate the contrast ratio between two colors.
     * Currently, only the RGBA format is supported.
     */
    backgroundColor?: string;
    /**
     * @hidden
     */
    _adaptive?: boolean;
}

/**
 * @hidden
 */
export declare interface ColorPickerHandle {
    element: HTMLSpanElement | null;
    value?: string;
}

/**
 * The settings of the ColorPalette that is nested inside the popup of the ColorPicker
 * ([see example]({% slug customizecolorpicker_colorpicker %}#toc-customizing-the-palette-popup)).
 */
export declare interface ColorPickerPaletteSettings {
    /**
     * Specifies the set of colors.
     * Provides a set of predefined palette presets (for example, `office`, `basic`, and `apex`)
     * and enables you to implement a custom color palette.
     * Defaults to the `office` preset.
     *
     * The supported values are:
     * * The name of the predefined palette preset (for example, `office`, `basic`, and `apex`).
     * * A string with comma-separated colors.
     * * A string array.
     */
    palette?: string | Array<string>;
    /**
     * Specifies the number of columns that will be displayed.
     * Defaults to `10`.
     */
    columns?: number;
    /**
     * Specifies the size of a color cell.
     *
     * The possible values are:
     * * (Default) `24`
     * * `{ width: number, height: number }`
     */
    tileSize?: number | TileSize;
}

/**
 * The settings of the popup container of the ColorPicker.
 */
export declare interface ColorPickerPopupSettings {
    /**
     * Controls the popup animation. By default, the open and close animations are enabled.
     */
    animate?: boolean | PopupAnimation;
    /**
     * Specifies a list of CSS classes that will be added to the Popup element.
     */
    className?: string | Array<string>;
}

/**
 * Represents the props of the [KendoReact ColorPicker component]({% slug overview_colorpicker %}).
 */
export declare interface ColorPickerProps {
    /**
     * The default value of the ColorPicker
     * ([see example]({% slug default_value_colorpicker %})).
     *
     * @example
     * ```jsx
     * <ColorPicker defaultValue="#ff0000" />
     * ```
     */
    defaultValue?: string;
    /**
     * Specifies the value of the ColorPicker. Currently, only the RGBA format is supported.
     *
     * @example
     * ```jsx
     * <ColorPicker value="rgba(255, 0, 0, 1)" />
     * ```
     */
    value?: string;
    /**
     * Overrides the validity state of the component.
     * If `valid` is set, the `required` property will be ignored.
     *
     * This property is part of the [FormComponentProps]({% slug api_common_formcomponentprops %}) interface.
     */
    valid?: boolean;
    /**
     * Sets the disabled state of the ColorPicker
     * ([see example]({% slug disabled_colorpicker %})).
     *
     * @example
     * ```jsx
     * <ColorPicker disabled={true} />
     * ```
     */
    disabled?: boolean;
    /**
     * Sets the `tabIndex` property of the ColorPicker.
     * Defaults to `0`.
     */
    tabIndex?: number;
    /**
     * Sets the `title` property of the ColorPicker.
     */
    title?: string;
    /**
     * **Deprecated**. Use `views` prop instead.
     *
     * @deprecated
     */
    view?: ColorPickerView;
    /**
     * Specifies the views that will be rendered in the popup. By default both the gradient and palette views will be rendered.
     *
     * @default ['gradient', 'palette']`
     */
    views?: ColorPickerView[];
    /**
     * Sets the initially active view in the popup when both 'gradient' and 'palette' views are rendered.
     * Use with the `views` property.
     *
     * @default 'gradient''
     */
    activeView?: ColorPickerView;
    /**
     * Represents the `dir` HTML attribute.
     */
    dir?: string;
    /**
     * Defines the name of an [existing icon in the KendoReact theme]({% slug icons %}).
     * You have to provide only the name of the icon without the `k-icon` or the `k-i-` prefixes.
     * For example, `edit-tools` will be parsed to `k-icon k-i-edit-tools`
     * ([see example]({% slug customizecolorpicker_colorpicker %}#displaying-custom-icons)).
     */
    icon?: string;
    /**
     * Defines the SVG icon.
     */
    svgIcon?: SVGIcon;
    /**
     * The class name which displays an icon in the ColorPicker button
     * ([see example]({% slug customizecolorpicker_colorpicker %}#toc-displaying-custom-icons)).
     */
    iconClassName?: string;
    /**
     * Configures the ColorGradient that is displayed in the ColorPicker popup
     * ([see example]({% slug customizecolorpicker_colorpicker %}#toc-customizing-the-gradient-popup)).
     */
    gradientSettings?: ColorPickerGradientSettings;
    /**
     * Configures the ColorPalette that is displayed in the ColorPicker popup
     * ([see example]({% slug customizecolorpicker_colorpicker %}#toc-customizing-the-palette-popup)).
     */
    paletteSettings?: ColorPickerPaletteSettings;
    /**
     * Configures the FlatColorPicker that is displayed in the ColorPicker popup via `views` property.
     */
    flatColorPickerSettings?: FlatColorPickerProps;
    /**
     * Configures the popup of the ColorPicker.
     */
    popupSettings?: ColorPickerPopupSettings;
    /**
     * Sets the open and close state of the ColorPicker.
     */
    open?: boolean;
    /**
     * Specifies the id of the component.
     */
    id?: string;
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Represent the label of the component.
     */
    ariaLabel?: string;
    /**
     * The event handler that will be fired when the user edits the value.
     */
    onChange?: (event: ColorPickerChangeEvent) => void;
    /**
     * The event handler that will be fired when ColorPicker is focused.
     */
    onFocus?: (event: ColorPickerFocusEvent) => void;
    /**
     * The event handler that will be fired when ColorPicker is blurred.
     */
    onBlur?: (event: ColorPickerBlurEvent) => void;
    /**
     * The event handler that will be fired when the left side of the ColorPicker is clicked.
     */
    onActiveColorClick?: (event: ColorPickerActiveColorClick) => void;
    /**
     * Configures the `size` of the ColorPicker.
     *
     * The available options are:
     * - `small`
     * - `medium`
     * - `large`
     * - `null`&mdash;This option removes the built-in size styles of the ColorPicker. Allows for custom `padding`.
     *
     * @default `medium`
     *
     * @example
     * ```jsx
     * <ColorPicker size="large" />
     * ```
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `roundness` of the ColorPicker.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a rounded `className`.
     *
     * @default `medium`
     */
    rounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Configures the `fillMode` of the ColorPicker.
     *
     * The available options are:
     * - solid
     * - outline
     * - flat
     * - null&mdash;Does not set a fillMode `className`.
     *
     * @default `solid`
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * Sets additional classes to the ColorPicker.
     */
    className?: string;
    /**
     * Providing different rendering of the popup element based on the screen dimensions.
     *
     * @default `false`
     *
     * @example
     * ```jsx
     * <ColorPicker adaptive={true} />
     * ```
     */
    adaptive?: boolean;
    /**
     * Specifies the text that is rendered as title in the adaptive popup(action sheet).
     * Applicable only when `adaptive` is set to `true`.
     * If not provided, the title will be the same as the label.
     *
     * @example
     * ```jsx
     * <ColorPicker adaptiveTitle="Adaptive Popup Title" />
     * ```
     */
    adaptiveTitle?: string;
    /**
     * Specifies the text that is rendered as subtitle in the adaptive popup(action sheet).
     * Applicable only when `adaptive` is set to `true`.
     *
     * @example
     * ```jsx
     * <ColorPicker adaptiveSubtitle="Adaptive Popup Subtitle" />
     * ```
     */
    adaptiveSubtitle?: string;
}

/**
 * Represents the PropsContext of the `ColorPicker` component.
 * Used for global configuration of all `ColorPicker` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const ColorPickerPropsContext: React_2.Context<(p: ColorPickerProps) => ColorPickerProps>;

/**
 * Specifies the view which the ColorPicker will render in the popup
 * ([see example]({% slug views_colorpicker %})).
 *
 * The possible values are:
 * * `palette`
 * * `gradient`
 * * **Deprecated** `combo`
 */
export declare type ColorPickerView = 'gradient' | 'palette' | 'combo';

declare type Direction = 'ltr' | 'rtl';

/**
 * Represents the [KendoReact FlatColorPicker component]({% slug overview_flatcolorpicker %}).
 * Accepts properties of type [FlatColorPickerProps]({% slug api_inputs_flatcolorpickerprops %}). Obtaining the [FlatColorPickerHandle]({% slug api_inputs_flatcolorpickerhandle %}).
 *
 * @example
 * ```jsx
 * class App extends React.Component {
 *     render() {
 *         return <FlatColorPicker />;
 *     }
 * }
 * ReactDOM.render(<App />, document.querySelector('my-app'));
 * ```
 */
export declare const FlatColorPicker: React_2.ForwardRefExoticComponent<FlatColorPickerProps & React_2.RefAttributes<FlatColorPickerHandle | null>>;

/**
 * The arguments for the `onChange` FlatColorPicker event.
 */
export declare interface FlatColorPickerChangeEvent {
    /**
     * The current value of the FlatColorPicker.
     */
    value: string | undefined;
    /**
     * A React Synthetic Event.
     */
    syntheticEvent: React_2.SyntheticEvent<any>;
    /**
     * A native DOM event.
     */
    nativeEvent: any;
}

/**
 * Represents the target (element and props) of the FlatColorPicker.
 */
export declare interface FlatColorPickerHandle {
    /**
     * The current element or `null` if there is none.
     */
    element: HTMLDivElement | null;
    /**
     * The props values of the FlatColorPicker.
     */
    props: FlatColorPickerProps;
    /**
     * The focus event callback.
     */
    focus: () => void;
    /**
     * The current value of the FlatColorPicker.
     */
    value: string | undefined;
}

/**
 * Represents the properties of [FlatColorPicker]({% slug api_inputs_flatcolorpicker %}) component.
 */
export declare interface FlatColorPickerProps {
    /**
     * Sets the `id` property of the top `div` element of the FlatColorPicker.
     */
    id?: string;
    /**
     * Sets additional CSS styles to the FlatColorPicker.
     */
    style?: React_2.CSSProperties;
    /**
     * Sets additional classes to the FlatColorPicker.
     */
    className?: string;
    /**
     * Sets the color value.
     */
    value?: string;
    /**
     * Sets the default color value.
     */
    defaultValue?: string;
    /**
     * The event handler that will be fired when the user changes the preview color.
     */
    onPreviewChange?: (event: FlatColorPickerChangeEvent) => void;
    /**
     * The event handler that will be fired when the user click the "Apply" button or on blur when the "Apply" button is not present.
     */
    onChange?: (event: FlatColorPickerChangeEvent) => void;
    /**
     * Specifies whether we should display the opacity slider to allow selection of transparency.
     *
     * @default true
     */
    opacity?: boolean;
    /**
     * Sets the default input format in the gradient input editor.
     *
     * @default 'rgb'
     */
    format?: 'hex' | 'rgba' | 'rgb';
    /**
     * Sets the `tabIndex` property of the FlatColorPicker.
     */
    tabIndex?: number;
    /**
     * Represents the label of the FlatColorPicker component.
     */
    ariaLabel?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Determines whether the FlatColorPicker is disabled.
     */
    disabled?: boolean;
    /**
     * **Deprecated**. Use `views` prop instead.
     *
     * @deprecated
     */
    view?: 'ColorGradient' | 'ColorPalette' | undefined;
    /**
     * Specifies the views that will be rendered. By default both the gradient and palette views will be rendered.
     *
     * @default ['gradient', 'palette']`
     */
    views?: ColorPickerView[];
    /**
     * Sets the initially active view when both 'gradient' and 'palette' views are rendered.
     * Use with the `views` property.
     *
     * @default 'gradient''
     */
    activeView?: ColorPickerView;
    /**
     * Sets custom header component.
     */
    header?: React_2.ComponentType;
    /**
     * Specifies whether clear button will be rendered in the header.
     */
    showClearButton?: boolean;
    /**
     * Specifies whether preview and revert color boxes will be rendered in the header.
     */
    showPreview?: boolean;
    /**
     * Specifies whether action buttons will be rendered in the footer.
     */
    showButtons?: boolean;
    /**
     * Configures the `size` of the FlatColorPicker.
     *
     * The available options are:
     * - `small`
     * - `medium`
     * - `large`
     * - `null`&mdash;This option removes the the built-in size styles of the FlatColorPicker. Allows for custom `padding`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * @hidden
     */
    _gradientSettings?: ColorPickerGradientSettings;
    /**
     * @hidden
     */
    _paletteSettings?: ColorPickerPaletteSettings;
    /**
     * @hidden
     */
    setAdaptiveModeValue?: (value: any) => void;
    /**
     * @hidden
     */
    setOpen?: (value: boolean) => void;
}

export { FormComponentValidity }

/**
 * @hidden
 */
declare interface HSVA {
    h?: number;
    s?: number;
    v?: number;
    a?: number;
}

/**
 * Represents the [KendoReact Input component]({% slug overview_input %}).
 *
 * Accepts properties of type [InputProps]({% slug api_inputs_inputprops %}).
 * Obtaining the `ref` returns an object of type [InputHandle]({% slug api_inputs_inputhandle %}).
 */
export declare const Input: React_2.ForwardRefExoticComponent<InputProps & React_2.RefAttributes<InputHandle | null>>;

/**
 * The arguments for the `change` event of the Input.
 */
export declare interface InputChangeEvent extends BaseEvent<InputHandle> {
    /**
     * The current value of the Input.
     */
    value: string;
}

/**
 * Represents the KendoReact InputClearValue component.
 */
export declare const InputClearValue: React_2.ForwardRefExoticComponent<InputClearValueProps & React_2.RefAttributes<InputClearValueHandle>>;

/**
 * Represent the `ref` of the `InputClearValue` component.
 */
export declare type InputClearValueHandle = {
    element: HTMLSpanElement | null;
};

/**
 * Represents the `props` of the `InputClearValue` component.
 */
export declare interface InputClearValueProps extends React_2.HTMLAttributes<HTMLSpanElement> {
    /**
     * @hidden
     */
    unstyled?: InputsClassStructure;
}

/**
 * Represent the `ref` target of the Input component.
 */
export declare interface InputHandle {
    /**
     * Gets the native input element of the Input component.
     */
    element: HTMLInputElement | null;
    /**
     * Gets the `name` property of the Input.
     */
    name: string | undefined;
    /**
     *The props of the InputHandle component.
     */
    props: InputProps;
    /**
     * Represents the validity state into which the Input is set.
     */
    validity: FormComponentValidity;
    /**
     * Gets the value of the Input.
     */
    value: string | string[] | number | undefined;
}

/**
 * Represents the KendoReact InputPrefix component.
 */
export declare const InputPrefix: React_2.ForwardRefExoticComponent<InputPrefixProps & React_2.RefAttributes<InputPrefixHandle>>;

/**
 * Represent the `ref` of the `InputPrefix` component.
 */
export declare interface InputPrefixHandle {
    element: HTMLSpanElement | null;
}

/**
 * Represents the `props` of the `InputPrefix` component.
 */
export declare interface InputPrefixProps extends React_2.HTMLAttributes<HTMLSpanElement> {
    /**
     * Sets the `orientation` property of the `InputPrefix` component.
     */
    orientation?: 'horizontal' | 'vertical';
}

/**
 * Represents the props of the [KendoReact Input component]({% slug overview_input %}).
 * Extends the [native input props](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement).
 */
export declare interface InputProps extends Omit_2<React_2.InputHTMLAttributes<HTMLInputElement>, 'onChange'>, FormComponentProps {
    /**
     * Renders a floating label for the Input component.
     */
    label?: React_2.ReactNode;
    /**
     * Sets a `className` for the floating label.
     */
    labelClassName?: string;
    /**
     * Represents the Input value.
     */
    value?: string | string[] | number;
    /**
     * Represents the Input default value.
     */
    defaultValue?: string | string[];
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Defines a string value that labels an interactive element.
     */
    ariaLabel?: string;
    /**
     * Represents the `autoFocus` HTML attribute that will be applied to the input element of the Input. (Defaults to `false`)
     */
    autoFocus?: boolean;
    /**
     * Triggered after value change.
     */
    onChange?: (event: InputChangeEvent) => void;
    /**
     * @hidden
     */
    unstyled?: InputsClassStructure;
    /**
     * @hidden
     */
    visited?: boolean;
    /**
     * @hidden
     */
    touched?: boolean;
    /**
     * @hidden
     */
    modified?: boolean;
}

/**
 * Represents the PropsContext of the `Input` component.
 * Used for global configuration of all `Input` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const InputPropsContext: React_2.Context<(p: InputProps) => InputProps>;

/**
 * Represents the KendoReact InputSeparator component.
 */
export declare const InputSeparator: React_2.ForwardRefExoticComponent<InputSeparatorProps & React_2.RefAttributes<InputSeparatorHandle>>;

/**
 * Represent the `ref` of the `InputSeparator` component.
 */
export declare interface InputSeparatorHandle {
    element: HTMLSpanElement | null;
}

/**
 * Represents the `props` of the `InputSeparator` component.
 */
export declare interface InputSeparatorProps extends React_2.HTMLAttributes<HTMLSpanElement> {
    /**
     * Sets the `orientation` property of the `InputSeparator` component.
     */
    orientation?: 'horizontal' | 'vertical';
}

/**
 * @hidden
 */
export declare const inputsMessages: {
    "numerictextbox.increment": string;
    "numerictextbox.decrement": string;
    "slider.increment": string;
    "slider.decrement": string;
    "slider.dragTitle": string;
    "colorGradient.r": string;
    "colorGradient.g": string;
    "colorGradient.b": string;
    "colorGradient.a": string;
    "colorGradient.hex": string;
    "colorGradient.contrastRatio": string;
    "colorGradient.colorGradientAALevel": string;
    "colorGradient.colorGradientAAALevel": string;
    "colorGradient.colorGradientPass": string;
    "colorGradient.colorGradientFail": string;
    "colorGradient.hueSliderLabel": string;
    "colorGradient.alphaSliderLabel": string;
    "colorGradient.toggleInputsButton": string;
    "flatColorPicker.cancelBtn": string;
    "flatColorPicker.applyBtn": string;
    "flatColorPicker.colorGradientBtn": string;
    "flatColorPicker.colorPaletteBtn": string;
    "flatColorPicker.clearBtn": string;
    "colorPicker.adaptiveTitle": string;
    "checkbox.validation": string;
    "checkbox.optionalText": string;
    "radioButton.validation": string;
    "switch.validation": string;
    "colorPicker.dropdownButtonAriaLabel": string;
    "rating.ariaLabel": string;
    "signature.clear": string;
    "signature.maximize": string;
    "signature.minimize": string;
};

/**
 * @hidden
 */
export declare interface InputState {
    value?: string | string[] | number;
}

/**
 * Represents the KendoReact InputSuffix component.
 */
export declare const InputSuffix: React_2.ForwardRefExoticComponent<React_2.HTMLAttributes<HTMLSpanElement> & {
    /**
     * Sets the `orientation` property of the `InputSuffix` component.
     */
    orientation?: "vertical" | "horizontal" | undefined;
} & React_2.RefAttributes<InputSuffixHandle>>;

/**
 * Represent the `ref` of the `InputSuffix` component.
 */
export declare type InputSuffixHandle = {
    element: HTMLSpanElement | null;
};

/**
 * Represents the `props` of the `InputSuffix` component.
 */
export declare type InputSuffixProps = React_2.HTMLAttributes<HTMLSpanElement> & {
    /**
     * Sets the `orientation` property of the `InputSuffix` component.
     */
    orientation?: 'horizontal' | 'vertical';
};

/**
 * Represents the KendoReact InputValidationIcon component.
 */
export declare const InputValidationIcon: React_2.ForwardRefExoticComponent<IconProps & SvgIconProps & React_2.RefAttributes<InputValidationIconHandle>>;

/**
 * Represent the `ref` of the `InputValidationIcon` component.
 */
export declare type InputValidationIconHandle = IconHandle & SvgIconHandle;

/**
 * Represents the `props` of the `InputValidationIcon` component.
 */
export declare type InputValidationIconProps = IconProps & SvgIconProps;

/**
 * @hidden
 */
export declare const isCorrectValue: (min: number, max: number, step: number, value: number) => boolean;

/**
 * @hidden
 */
export declare const isHalf: (index: number, value: number, step: number) => boolean;

/**
 * @hidden
 */
export declare const isSelected: (index: number, value: number | null, step: number, selection: 'single' | 'continues') => boolean;

/** @hidden */
export declare type MaskedTextBox = MaskedTextBoxHandle;

/**
 * Represents the props of the [KendoReact MaskedTextBox component]({% slug overview_maskedtextbox %}).
 *
 * Accepts properties of type [MaskedTextBoxProps]({% slug api_inputs_maskedtextboxprops %}).
 * Obtaining the `ref` returns an object of type [MaskedTextBoxHandle]({% slug api_inputs_maskedtextboxhandle %}).
 */
export declare const MaskedTextBox: React_2.ForwardRefExoticComponent<MaskedTextBoxProps & React_2.RefAttributes<any>>;

/**
 * The arguments for the `change` event of the MaskedTextBox.
 */
export declare interface MaskedTextBoxChangeEvent extends MaskedTextBoxEvent {
    /**
     * Specifies the start of the selection which will be set to the MaskedTextBox when it is updated.
     */
    selectionStart: number;
    /**
     * Specifies the end of the selection which will be set to the MaskedTextBox when it is updated.
     */
    selectionEnd: number;
    /**
     * The current value of the component.
     */
    value: any;
}

/**
 * The arguments for a MaskedTextBox event.
 */
export declare interface MaskedTextBoxEvent {
    /**
     * A native DOM event.
     */
    nativeEvent: Event;
    /**
     * A React [`SyntheticEvent`](https://react.dev/learn/responding-to-events).
     */
    syntheticEvent: React.SyntheticEvent<HTMLElement>;
    /**
     * An event target.
     */
    target: MaskedTextBox;
}

/**
 * Represent the `ref` of the MaskedTextBox component.
 */
export declare interface MaskedTextBoxHandle extends Pick<MaskedTextBoxWithoutContext, keyof MaskedTextBoxWithoutContext> {
    /**
     * Gets the element of the MaskedTextBox.
     *
     * ```jsx
     * class App extends React.Component {
     * constructor(props) {
     *  super(props);
     * }
     * element = null;
     * render() {
     *  return (
     *      <div>
     *          <MaskedTextBox
     *              ref={(component) =>
     *                  this.element = component ? component.element : null}
     *          />
     *          <button onClick={() => console.log(this.element)}>console.log the element</button>
     *      </div>
     *  );
     * }
     * }
     *
     * ReactDOM.render(
     * <App />,
     * document.getElementsByTagName('my-app')[0]
     * );
     * ```
     */
    element: HTMLInputElement | null;
    /**
     * Gets the `name` property of the MaskedTextBox.
     */
    name: string | undefined;
    /**
     * Gets the raw value without the mask of the MaskedTextBox.
     */
    rawValue: string;
    /**
     * Represents the validity state into which the MaskedTextBox is set.
     */
    validity: FormComponentValidity;
    /**
     * Gets the value with the mask of the MaskedTextBox.
     */
    value: string;
}

/**
 * Represents the props of the [KendoReact MaskedTextBox component]({% slug overview_maskedtextbox %}).
 */
export declare interface MaskedTextBoxProps extends FormComponentProps {
    /**
     * Sets a class of the MaskedTextBox DOM element.
     *
     * @example
     * ```jsx
     * <MaskedTextBox className="custom-class" />
     * ```
     */
    className?: string;
    /**
     * Sets additional CSS styles to the MaskedTextBox DOM element.
     *
     * @example
     * ```jsx
     * <MaskedTextBox style={{ color: 'red' }} />
     * ```
     */
    style?: React.CSSProperties;
    /**
     * Specifies the value of the MaskedTextBox.
     *
     * @example
     * ```jsx
     * <MaskedTextBox value="123-45-6789" />
     * ```
     */
    value?: string;
    /**
     * Specifies the initial value. Leaves the subsequent updates uncontrolled.
     */
    defaultValue?: string;
    /**
     * Specifies the input placeholder.
     *
     * @example
     * ```jsx
     * <MaskedTextBox placeholder="Enter text here" />
     * ```
     */
    placeholder?: string;
    /**
     * Sets the title of the `input` element of the MaskedTextBox.
     */
    title?: string;
    /**
     * Represents the `dir` HTML attribute.
     *
     * @example
     * ```jsx
     * <MaskedTextBox dir="rtl" />
     * ```
     */
    dir?: string;
    /**
     * Sets the `tabIndex` property of the MaskedTextBox.
     */
    tabIndex?: number;
    /**
     * Specifies the `accessKey` of the MaskedTextBox.
     */
    accessKey?: string;
    /**
     * Specifies the width of the MaskedTextBox.
     *
     * @example
     * ```jsx
     * <MaskedTextBox width="200px" />
     * ```
     */
    width?: number | string;
    /**
     * Determines whether the MaskedTextBox is disabled.
     *
     * @example
     * ```jsx
     * <MaskedTextBox disabled={true} />
     * ```
     */
    disabled?: boolean;
    /**
     * Renders a floating label for the MaskedTextBox.
     */
    label?: React.ReactNode;
    /**
     * Sets the `id` of the `input` DOM element.
     */
    id?: string;
    /**
     * Sets a custom prefix to the MaskedTextBox component.
     */
    prefix?: CustomComponent<any>;
    /**
     * Sets a custom suffix to the MaskedTextBox component.
     */
    suffix?: CustomComponent<any>;
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Determines whether the MaskedTextBox is in its read-only state.
     */
    readonly?: boolean;
    /**
     * Represents a prompt character for the masked value. Defaults to `_`.
     */
    prompt?: string;
    /**
     * Indicates a character which represents an empty position in the raw value. Defaults to ` `.
     */
    promptPlaceholder?: string;
    /**
     * Indicates whether to include literals in the raw value. Defaults to `false`.
     */
    includeLiterals?: boolean;
    /**
     * Determines whether the built-in mask validator is enforced when a form is validated. Defaults to `true`.
     */
    maskValidation?: boolean;
    /**
     * Represents the current mask. If no mask is set, the component behaves as a standard `type="text"` input.
     *
     * @example
     * ```jsx
     * <MaskedTextBox mask="(999) 000-0000" />
     * ```
     */
    mask?: string;
    /**
     * Represents the RegExp-based mask validation array.
     */
    rules?: {
        [key: string]: RegExp;
    };
    /**
     * Represents the beginning and ending of the selected portion of the input content that will be applied the next time when the MaskedTextBox is rendered.
     */
    selection?: {
        start: number;
        end: number;
    };
    /**
     * Determines the event handler that will be fired when the user edits the value.
     *
     * @example
     * ```jsx
     * <MaskedTextBox onChange={(e) => console.log(e.value)} />
     * ```
     */
    onChange?: (event: MaskedTextBoxChangeEvent) => void;
    /**
     * Fires each time the user focuses the MaskedTextBox.
     */
    onFocus?: (event: MaskedTextBoxEvent) => void;
    /**
     * Fires each time the MaskedTextBox gets blurred.
     */
    onBlur?: (event: MaskedTextBoxEvent) => void;
    /**
     * Configures the `size` of the MaskedTextBox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `roundness` of the MaskedTextBox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a rounded `className`.
     *
     * @default `medium`
     */
    rounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Configures the `fillMode` of the MaskedTextBox.
     *
     * The available options are:
     * - solid
     * - outline
     * - flat
     * - null&mdash;Does not set a fillMode `className`.
     *
     * @default `solid`
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * Represents the `autoFocus` HTML attribute that will be applied to the input element of the MaskedTextBox. (Defaults to `false`)
     */
    autoFocus?: boolean;
    /**
     * @hidden
     */
    unstyled?: InputsClassStructure;
    /**
     * Sets the HTML attributes of the inner focusable input element.
     * Attributes which are essential for certain component functionalities cannot be changed.
     */
    inputAttributes?: React.InputHTMLAttributes<HTMLInputElement>;
}

/**
 * Represents the PropsContext of the `MaskedTextBox` component.
 * Used for global configuration of all `MaskedTextBox` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const MaskedTextBoxPropsContext: React_2.Context<(p: MaskedTextBoxProps) => MaskedTextBoxProps>;

/**
 * @hidden
 */
declare interface MaskedTextBoxState {
    focused?: boolean;
    value?: string;
}

/** @hidden */
export declare class MaskedTextBoxWithoutContext extends React_2.Component<MaskedTextBoxProps, MaskedTextBoxState> implements FormComponent {
    static displayName: string;
    /**
     * @hidden
     */
    static propTypes: {
        value: default_2.Requireable<string>;
        defaultValue: default_2.Requireable<string>;
        placeholder: default_2.Requireable<string>;
        title: default_2.Requireable<string>;
        dir: default_2.Requireable<string>;
        id: default_2.Requireable<string>;
        style: default_2.Requireable<object>;
        className: default_2.Requireable<string>;
        prefix: default_2.Requireable<any>;
        suffix: default_2.Requireable<any>;
        ariaLabelledBy: default_2.Requireable<string>;
        ariaDescribedBy: default_2.Requireable<string>;
        width: default_2.Requireable<NonNullable<string | number | null | undefined>>;
        tabIndex: default_2.Requireable<number>;
        accessKey: default_2.Requireable<string>;
        disabled: default_2.Requireable<boolean>;
        readonly: default_2.Requireable<boolean>;
        prompt: default_2.Requireable<string>;
        promptPlaceholder: default_2.Requireable<string>;
        includeLiterals: default_2.Requireable<boolean>;
        maskValidation: default_2.Requireable<boolean>;
        mask: default_2.Requireable<string>;
        rules: (props: MaskedTextBoxProps, propName: string, componentName: string) => Error | null;
        selection: default_2.Requireable<default_2.InferProps<{
            start: default_2.Validator<number>;
            end: default_2.Validator<number>;
        }>>;
        name: default_2.Requireable<string>;
        label: default_2.Requireable<default_2.ReactNodeLike>;
        validationMessage: default_2.Requireable<string>;
        required: default_2.Requireable<boolean>;
        valid: default_2.Requireable<boolean>;
        validityStyles: default_2.Requireable<boolean>;
        onChange: default_2.Requireable<(...args: any[]) => any>;
        size: default_2.Requireable<"small" | "large" | "medium" | null | undefined>;
        rounded: default_2.Requireable<"small" | "large" | "medium" | "full" | null | undefined>;
        fillMode: default_2.Requireable<"flat" | "solid" | "outline" | null | undefined>;
        autoFocus: default_2.Requireable<boolean>;
        inputAttributes: default_2.Requireable<object>;
    };
    /**
     * @hidden
     */
    static defaultProps: {
        prompt: string;
        promptPlaceholder: string;
        includeLiterals: boolean;
        maskValidation: boolean;
        rules: {
            [key: string]: RegExp;
        };
        validityStyles: boolean;
        prefix: (_: any) => null;
        suffix: (_: any) => null;
        size: "small" | "large" | "medium" | null | undefined;
        rounded: "small" | "large" | "medium" | "full" | null | undefined;
        fillMode: "flat" | "solid" | "outline" | null | undefined;
        autoFocus: boolean;
    };
    /**
     * @hidden
     */
    state: MaskedTextBoxState;
    private _inputId;
    private _service;
    private _isPasted;
    private _selection;
    private _input;
    private _valueDuringOnChange?;
    /**
     * @hidden
     */
    focus: () => void;
    /**
     * Gets the element of the MaskedTextBox.
     *
     * @return - An `HTMLInputElement`.
     *
     * @example
     * ```jsx
     * class App extends React.Component {
     *     constructor(props) {
     *         super(props);
     *     }
     *     element = null;
     *     render() {
     *         return (
     *             <div>
     *                 <MaskedTextBox
     *                     ref={(component) =>
     *                         this.element = component ? component.element : null}
     *                 />
     *                 <button onClick={() => console.log(this.element)}>console.log the element</button>
     *             </div>
     *         );
     *     }
     * }
     *
     * ReactDOM.render(
     *     <App />,
     *     document.getElementsByTagName('my-app')[0]
     * );
     * ```
     */
    get element(): HTMLInputElement | null;
    /**
     * Gets the value with the mask of the MaskedTextBox.
     */
    get value(): string;
    /**
     * Gets the raw value without the mask of the MaskedTextBox.
     */
    get rawValue(): string;
    /**
     * Represents the validity state into which the MaskedTextBox is set.
     */
    get validity(): FormComponentValidity;
    /**
     * @hidden
     */
    protected get validityStyles(): boolean;
    /**
     * @hidden
     */
    protected get required(): boolean;
    /**
     * Gets the `name` property of the MaskedTextBox.
     */
    get name(): string | undefined;
    /**
     * @hidden
     */
    componentDidUpdate(prevProps: MaskedTextBoxProps, prevState: MaskedTextBoxState): void;
    /**
     * @hidden
     */
    componentDidMount(): void;
    /**
     * @hidden
     */
    render(): JSX.Element;
    private pasteHandler;
    private onChangeHandler;
    private focusHandler;
    private blurHandler;
    private triggerOnChange;
    private updateService;
    private get rules();
    private setValidity;
}

/**
 * @hidden
 */
export declare const maskingChanged: (prev: MaskedTextBoxProps, next: MaskedTextBoxProps) => boolean;

/**
 * @hidden
 */
export declare const numericDecreaseValue = "numerictextbox.decrement";

/**
 * @hidden
 */
export declare const numericIncreaseValue = "numerictextbox.increment";

/**
 * Represents the [KendoReact NumericTextBox component]({% slug overview_numerictextbox %}).
 */
export declare const NumericTextBox: React_2.ForwardRefExoticComponent<NumericTextBoxProps & React_2.RefAttributes<NumericTextBoxHandle | null>>;

/**
 * The arguments for the `onBlur` NumericTextBox event.
 */
export declare interface NumericTextBoxBlurEvent extends BaseEvent<NumericTextBoxHandle> {
}

/**
 * The arguments for the `change` event of the NumericTextBox.
 */
export declare interface NumericTextBoxChangeEvent extends BaseEvent<NumericTextBoxHandle> {
    /**
     * The current value of the NumericTextBox.
     */
    value: number | null;
}

/**
 * The arguments for the `onFocus` NumericTextBox event.
 */
export declare interface NumericTextBoxFocusEvent extends BaseEvent<NumericTextBoxHandle> {
}

/**
 * The NumericTextBox ref.
 */
export declare interface NumericTextBoxHandle {
    /**
     * The NumericTextBox element.
     */
    element: HTMLInputElement | null;
    /**
     * Focus the NumericTextBox.
     */
    focus: () => void;
    /**
     * Gets the `name` property of the NumericTextBox.
     */
    name: string | undefined;
    /**
     * Gets the value of the NumericTextBox.
     */
    value: number | null;
    /**
     * Represents the validity state into which the NumericTextBox is set.
     */
    validity: FormComponentValidity;
    /**
     * @hidden
     */
    props: NumericTextBoxProps;
    /**
     * @hidden
     */
    validityStyles: boolean;
    /**
     * @hidden
     */
    required: boolean;
}

declare type NumericTextBoxInputType = 'tel' | 'text' | 'number';

/**
 * Represents the props of the [KendoReact NumericTextBox component]({% slug overview_numerictextbox %}).
 */
export declare interface NumericTextBoxProps extends FormComponentProps, Omit<React.HTMLAttributes<HTMLElement>, 'defaultValue' | 'prefix' | 'onChange' | 'onBlur' | 'onFocus'> {
    /**
     * Sets a class of the NumericTextBox DOM element.
     */
    className?: string;
    /**
     * Specifies the value of the NumericTextBox.
     */
    value?: number | null;
    /**
     * Specifies the initial value. Leaves the subsequent updates uncontrolled.
     */
    defaultValue?: number | null;
    /**
     * Specifies the value that is used to increment or decrement the value of the NumericTextBox ([see example]({% slug predefinedsteps_numerictextbox %})).
     */
    step?: number;
    /**
     * Specifies the number format which is used for formatting the value ([see example]({% slug formats_numerictextbox %})). If set to `an empty string` or `undefined`, the default format will be used. Format cannot contain decimal separators or numbers. Power signs are supported.
     */
    format?: string | NumberFormatOptions;
    /**
     * Specifies the width of the NumericTextBox.
     */
    width?: number | string;
    /**
     * Sets the `tabIndex` property of the NumericTextBox.
     */
    tabIndex?: number;
    /**
     * Specifies the `accessKey` of the NumericTextBox.
     */
    accessKey?: string;
    /**
     * Sets the title of the `input` element of the NumericTextBox.
     */
    title?: string;
    /**
     * Specifies the input placeholder.
     */
    placeholder?: string;
    /**
     * Specifies the smallest value that can be entered.
     */
    min?: number;
    /**
     * Specifies the greatest value that can be entered.
     */
    max?: number;
    /**
     * Specifies whether the **Up** and **Down** spin buttons will be rendered ([see example]({% slug spinbuttons_numerictextbox %})).
     */
    spinners?: boolean;
    /**
     * Determines whether the NumericTextBox is disabled.
     */
    disabled?: boolean;
    /**
     * Represents the `dir` HTML attribute.
     */
    dir?: string;
    /**
     * Specifies the name of the `input` DOM element.
     */
    name?: string;
    /**
     * Renders a floating label for the NumericTextBox.
     */
    label?: string;
    /**
     * Sets the `id` of the `input` DOM element.
     */
    id?: string;
    /**
     * Sets a custom prefix to the NumericTextBox component.
     */
    prefix?: CustomComponent<any>;
    /**
     * Sets a custom suffix to the NumericTextBox component.
     */
    suffix?: CustomComponent<any>;
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * The accessible label of the component.
     */
    ariaLabel?: string;
    /**
     * Sets the `type` of the `input` DOM element.
     *
     * The available options are:
     * - (Default) `tel`
     * - `text`
     */
    inputType?: NumericTextBoxInputType;
    /**
     * If enabled, the NumericTextBox will handle the `enter` key to range the current invalid value between `min` and `max` props.
     * The available options are:
     * - (Default) `true`
     * - `false`
     * Can be disabled when form submit is required on pressing the `enter` key.
     */
    rangeOnEnter?: boolean;
    /**
     * Determines whether the NumericTextBox is in its read-only state.
     */
    readOnly?: boolean;
    /**
     * Determines the event handler that will be fired when the user edits the value.
     */
    onChange?: (event: NumericTextBoxChangeEvent) => void;
    /**
     * The event handler that will be fired when NumericTextBox is focused.
     */
    onFocus?: (event: NumericTextBoxFocusEvent) => void;
    /**
     * The event handler that will be fired when NumericTextBox is blurred.
     */
    onBlur?: (event: NumericTextBoxBlurEvent) => void;
    /** @hidden */
    children?: React.ReactNode;
    /**
     * Configures the `size` of the NumericTextBox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `roundness` of the NumericTextBox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a rounded `className`.
     *
     * @default `medium`
     */
    rounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Configures the `fillMode` of the NumericTextBox.
     *
     * The available options are:
     * - solid
     * - outline
     * - flat
     * - null&mdash;Does not set a fillMode `className`.
     *
     * @default `solid`
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * Represents the `style` HTML attribute.
     */
    style?: React.CSSProperties;
    /**
     * Represents the input element `style` HTML attribute.
     */
    inputStyle?: React.CSSProperties;
    /**
     * Represents the `autoFocus` HTML attribute that will be applied to the input element of the NumericTextBox. (Defaults to `false`)
     */
    autoFocus?: boolean;
    /**
     * Sets the HTML attributes of the inner focusable input element.
     * Attributes which are essential for certain component functionalities cannot be changed.
     */
    inputAttributes?: React.InputHTMLAttributes<HTMLInputElement>;
}

/**
 * Represents the PropsContext of the `NumericTextBox` component.
 * Used for global configuration of all `NumericTextBox` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const NumericTextBoxPropsContext: React_2.Context<(p: NumericTextBoxProps) => NumericTextBoxProps>;

/**
 * @hidden
 */
declare interface NumericTextBoxState {
    eventValue: number | null | undefined;
    prevLooseValue: string | undefined;
    currentLooseValue: string | undefined;
    selectionStart: number | undefined;
    selectionEnd: number | undefined;
    decimalSelect: boolean;
    valueIsCorrected: boolean;
    valueIsOutOfRange: boolean;
    focused: boolean;
    isPaste: boolean;
}

/**
 * @hidden
 */
declare type Omit_2<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;

/**
 * @hidden
 */
declare type Omit_3<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;

/**
 * @hidden
 */
declare type Omit_4<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;

/**
 * @hidden
 */
declare type Omit_5<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;

/**
 * @hidden
 */
export declare const PALETTEPRESETS: {
    basic: {
        colors: string[];
        columns: number;
    };
    office: {
        colors: string[];
        columns: number;
    };
    apex: {
        colors: string[];
        columns: number;
    };
    austin: {
        colors: string[];
        columns: number;
    };
    clarity: {
        colors: string[];
        columns: number;
    };
    slipstream: {
        colors: string[];
        columns: number;
    };
    metro: {
        colors: string[];
        columns: number;
    };
    flow: {
        colors: string[];
        columns: number;
    };
    hardcover: {
        colors: string[];
        columns: number;
    };
    trek: {
        colors: string[];
        columns: number;
    };
    verve: {
        colors: string[];
        columns: number;
    };
    monochrome: {
        colors: string[];
        columns: number;
    };
};

/**
 * Represents the [KendoReact RadioButton component]({% slug overview_radiobutton %}).
 *
 * Accepts properties of type [RadioButtonProps]({% slug api_inputs_radiobuttonprops %}).
 * Obtaining the `ref` returns an object of type [RadioButtonHandle]({% slug api_inputs_radiobuttonhandle %}).
 */
export declare const RadioButton: React_2.ForwardRefExoticComponent<RadioButtonProps & React_2.RefAttributes<RadioButtonHandle | null>>;

/**
 * The arguments for the `onBlur` RadioButton event.
 */
export declare interface RadioButtonBlurEvent extends BaseEvent<RadioButtonHandle> {
}

/**
 * The arguments for the `onChange` RadioButton event.
 */
export declare interface RadioButtonChangeEvent extends BaseEvent<RadioButtonHandle> {
    /**
     * The value of the selected RadioButton.
     */
    value: any;
}

/**
 * The arguments for the `onFocus` RadioButton event.
 */
export declare interface RadioButtonFocusEvent extends BaseEvent<RadioButtonHandle> {
}

/**
 * The RadioButton ref.
 */
export declare interface RadioButtonHandle {
    element: HTMLInputElement | null;
    focus: any;
}

/**
 * Represents the props of the [KendoReact RadioButton component]({% slug overview_radiobutton %}).
 * Extends the [native input props](https://developer.mozilla.org/en-US/docs/Web/API/HTMLInputElement).
 */
export declare interface RadioButtonProps extends Omit_4<React.InputHTMLAttributes<HTMLInputElement>, 'size' | 'onChange' | 'onFocus' | 'onBlur'> {
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    children?: any;
    /**
     * Specifies if the Radio button is checked.
     */
    checked?: boolean;
    /**
     * Specifies a list of CSS classes that will be added to the Radio button.
     */
    className?: string;
    /**
     * Specifies if the Radio button is disabled.
     */
    disabled?: boolean;
    /**
     * Specifies the current index of the Radio button.
     */
    index?: number;
    /**
     * Sets the `id` of the Radio button.
     */
    id?: string;
    /**
     * Configures the `size` of the RadioButton.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Sets the label of the Radio button ([see example]({% slug labels_radiobutton %})).
     */
    label?: string;
    /**
     * Sets the label position of the Radio button ([see example]({% slug labels_radiobutton %})).
     * Accepts two options: `before` or `after`. Defaults to `after`.
     */
    labelPlacement?: string;
    /**
     * Sets the `name` property of the Radio button.
     */
    name?: string;
    /**
     * Sets additional CSS styles to the Radio button.
     */
    style?: React.CSSProperties;
    /**
     * Sets the `tabIndex` property of the Radio button.
     * Defaults to `0`.
     */
    tabIndex?: number;
    /**
     * Overrides the validity state of the component.
     * If `valid` is set, the `required` property will be ignored.
     *
     * This property is part of the [FormComponentProps]({% slug api_common_formcomponentprops %}) interface.
     */
    valid?: boolean;
    /**
     * Sets the value to be submitted.
     */
    value?: any;
    /**
     * The event handler that will be fired when the changes the selected value.
     */
    onChange?: (event: RadioButtonChangeEvent) => void;
    /**
     * The event handler that will be fired when RadioButton is focused.
     */
    onFocus?: (event: RadioButtonFocusEvent) => void;
    /**
     * The event handler that will be fired when RadioButton is blurred.
     */
    onBlur?: (event: RadioButtonBlurEvent) => void;
}

/**
 * Represents the PropsContext of the `RadioButton` component.
 * Used for global configuration of all `RadioButton` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const RadioButtonPropsContext: React_2.Context<(p: RadioButtonProps) => RadioButtonProps>;

/**
 * Represents the [KendoReact RadioGroup component]({% slug overview_radiogroup %}).
 *
 * Accepts properties of type [RadioGroupProps]({% slug api_inputs_radiogroupprops %}).
 * Obtaining the `ref` returns an object of type [RadioGroupHandle]({% slug api_inputs_radiogrouphandle %}).
 */
export declare const RadioGroup: React_2.ForwardRefExoticComponent<RadioGroupProps & React_2.RefAttributes<RadioGroupHandle | null>>;

/**
 * The arguments for the `onChange` RadioGroup event.
 */
export declare interface RadioGroupChangeEvent extends BaseEvent<RadioGroupHandle> {
    /**
     * The value of the selected RadioButton.
     */
    value: any;
}

/**
 * The arguments for the `onFocus` RadioGroup event.
 */
export declare interface RadioGroupFocusEvent extends BaseEvent<RadioGroupHandle> {
}

/**
 * The RadioGroup ref.
 */
export declare interface RadioGroupHandle {
    element: HTMLUListElement | null;
    focus: any;
}

/**
 * Represents the props of the [KendoReact RadioGroup component]({% slug overview_radiobutton %}).
 */
export declare interface RadioGroupProps {
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     *
     * @example
     * ```jsx
     * <RadioGroup ariaDescribedBy="error-message" />
     * ```
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     *
     * @example
     * ```jsx
     * <RadioGroup ariaLabelledBy="group-label" />
     * ```
     */
    ariaLabelledBy?: string;
    /**
     * Specifies a list of CSS classes that will be added to the RadioGroup element.
     *
     * @example
     * ```jsx
     * <RadioGroup className="custom-class" />
     * ```
     */
    className?: string;
    /**
     * Specifies the value of the `id` attribute that will be added to the RadioGroup element.
     *
     * @example
     * ```jsx
     * <RadioGroup id="radio-group" />
     * ```
     */
    id?: string;
    /**
     * The collection of radio buttons that will be rendered in the RadioGroup ([see example]({% slug overview_radiobutton %})).
     *
     * @example
     * ```jsx
     * <RadioGroup data={[{ label: 'Option 1', value: 1 }, { label: 'Option 2', value: 2 }]} />
     * ```
     */
    data?: Array<RadioButtonProps>;
    /**
     * Sets the default checked state of a radio button when used in uncontrolled mode ([see example]({% slug overview_radiobutton %})).
     * The `checked` property is passed to the underlying `input` element.
     *
     * @example
     * ```jsx
     * <RadioGroup defaultValue={1} />
     * ```
     */
    defaultValue?: any;
    /**
     * Represents the `dir` HTML attribute. This is used to switch from LTR to RTL.
     *
     * @example
     * ```jsx
     * <RadioGroup dir="rtl" />
     * ```
     */
    dir?: string;
    /**
     * Disable all radio buttons ([see example]({% slug disabled_radiobutton %})).
     *
     * @example
     * ```jsx
     * <RadioGroup disabled={true} />
     * ```
     */
    disabled?: boolean;
    /**
     * Overrides the default component responsible for visualizing a single item.
     *
     * The default element is `li` with a [RadioButton]({% slug api_inputs_radiobutton %}) as `children`.
     *
     * @example
     * ```jsx
     * <RadioGroup item={(props) => <li>{props.label}</li>} />
     * ```
     */
    item?: React.ComponentType<HTMLAttributes<HTMLLIElement>>;
    /**
     * Sets the label position of the radio buttons.
     * Accepts two options: `before` or `after`. Defaults to `after`.
     *
     * @example
     * ```jsx
     * <RadioGroup labelPlacement="before" />
     * ```
     */
    labelPlacement?: string;
    /**
     * Specifies the radio group layout.
     *
     * @example
     * ```jsx
     * <RadioGroup layout="horizontal" />
     * ```
     */
    layout?: 'horizontal' | 'vertical';
    /**
     * Specifies the `name` property of the `input` DOM elements.
     *
     * @example
     * ```jsx
     * <RadioGroup name="options" />
     * ```
     */
    name?: string;
    /**
     * The event handler that will be fired when the changes the selected value.
     *
     * @example
     * ```jsx
     * <RadioGroup onChange={(event) => console.log(event.value)} />
     * ```
     */
    onChange?: (event: RadioGroupChangeEvent) => void;
    /**
     * The event handler that will be fired when Radio button is focused.
     *
     * @example
     * ```jsx
     * <RadioGroup onFocus={(event) => console.log('Focused')} />
     * ```
     */
    onFocus?: (event: RadioGroupFocusEvent) => void;
    /**
     * Sets additional CSS styles to the radio group.
     *
     * @example
     * ```jsx
     * <RadioGroup style={{ margin: '10px' }} />
     * ```
     */
    style?: React.CSSProperties;
    /**
     * Sets the default checked state of a radio button when used in controlled mode ([see example]({% slug controlled_radiogroup %})).
     * The `checked` property is passed to the underlying `input` element.
     *
     * @example
     * ```jsx
     * <RadioGroup value={1} />
     * ```
     */
    value?: string | number | null;
    /**
     * Overrides the validity state of the component.
     * If `valid` is set, the `required` property will be ignored.
     *
     * This property is part of the [FormComponentProps]({% slug api_common_formcomponentprops %}) interface.
     *
     * @example
     * ```jsx
     * <RadioGroup valid={false} />
     * ```
     */
    valid?: boolean;
}

/**
 * Represents the PropsContext of the `RadioGroup` component.
 * Used for global configuration of all `RadioGroup` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const RadioGroupPropsContext: React_2.Context<(p: RadioGroupProps) => RadioGroupProps>;

/**
 * The range object representing the value of the RangeSlider.
 */
declare type Range_2 = {
    /**
     * The start of the range.
     */
    start: number;
    /**
     * The end of the range.
     */
    end: number;
};
export { Range_2 as Range }

/**
 * @hidden
 */
export declare enum RANGE_ACTION {
    start = "start",
    end = "end",
    min = "min",
    max = "max",
    increase = "increase",
    decrease = "decrease",
    increaseLarge = "increaseLarge",
    decreaseLarge = "decreaseLarge"
}

/**
 * @hidden
 */
declare interface RangeAction extends RangeActionDispatch {
    step: number;
    largeStep: number;
    min: number;
    max: number;
}

/**
 * @hidden
 */
declare type RangeActionDispatch = {
    type: RANGE_ACTION;
    payload?: number;
    key?: string;
    event?: React_2.SyntheticEvent<any> | DraggableDragEvent;
    state?: Range_2;
};

/**
 * @hidden
 */
export declare const rangeReducer: (state: any, action: RangeAction) => any;

/**
 * Represents the [KendoReact RangeSlider component]({% slug overview_rangeslider %}).
 *
 * Accepts properties of type [RangeSliderProps]({% slug api_inputs_rangesliderprops %}).
 * Obtaining the `ref` returns an object of type [RangeSliderHandle]({% slug api_inputs_rangesliderhandle %}).
 *
 * @remarks
 * Supported children components are: {@link SliderLabel}.
 */
export declare const RangeSlider: React_2.ForwardRefExoticComponent<RangeSliderProps & React_2.RefAttributes<RangeSliderHandle | null>>;

/**
 * Represent the return type of RangeSliderChangeEvent.
 */
export declare interface RangeSliderChangeEvent {
    /**
     * The value from type Range - `start` and `end`.
     */
    value: Range_2;
    /**
     * The target of the RangeSliderChangeEvent from RangeSliderHandle.
     */
    target: RangeSliderHandle;
    /**
     * The event of the RangeSliderChangeEvent.
     */
    syntheticEvent: React_2.SyntheticEvent<any> | DraggableDragEvent;
}

/**
 * Represents the target(element and props) of the RangeSliderChangeEvent.
 */
export declare interface RangeSliderHandle {
    /**
     * The current element or `null` if there is no one.
     */
    element: HTMLDivElement | null;
    /**
     * The props values of the RangeSlider.
     */
    props: RangeSliderProps;
    /**
     * The focus event callback.
     */
    focus: () => void;
}

/**
 * Represents the properties of [RangeSlider](% slug api_inputs_rangeslider %) component.
 */
export declare interface RangeSliderProps extends FormComponentProps {
    /**
     * Sets the `id` property of the top div element of the RangeSlider.
     */
    id?: string;
    /**
     * Sets additional CSS styles to the RangeSlider.
     */
    style?: React_2.CSSProperties;
    /**
     * Sets additional classes to the RangeSlider.
     */
    className?: string;
    /**
     * The flexible values of type Range - `start and `end`.
     */
    value?: Range_2;
    /**
     * The default set values of type Range - `start` and `end`.
     */
    defaultValue?: Range_2;
    /**
     * Triggered after value change - gets outside access to the element, new values and the event type.
     */
    onChange?: (event: RangeSliderChangeEvent) => void;
    /**
     * Determines the children nodes.
     */
    children?: React_2.ReactNode;
    /**
     * Specifies the step by which the RangeSlider's value will be increased or decreased using the keyboard arrows. Defaults to `1`.
     */
    step?: number;
    /**
     * Specifies the step by which the RangeSlider's value will be increased or decreased using `pageUp` or `pageDown` keyboard buttons. Defaults to `10`.
     */
    largeStep?: number;
    /**
     * The minimum possible value of the RangeSlider.
     */
    min: number;
    /**
     * The maximum possible value of the RangeSlider.
     */
    max: number;
    /**
     * The RangeSlider orientation if true - vertical, else - horizontal.
     */
    vertical?: boolean;
    /**
     * Determines the disabled mode of the RangeSlider, if true - disabled.
     */
    disabled?: boolean;
    /**
     * The RangeSlider direction `ltr` or `rtl`.
     */
    dir?: Direction;
    /**
     * Sets the `tabIndex` attribute to the `start` drag handle.
     */
    startTabIndex?: number;
    /**
     * Sets the `tabIndex` attribute to the `end` drag handle.
     */
    endTabIndex?: number;
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
}

/**
 * Represents the PropsContext of the `RangeSlider` component.
 * Used for global configuration of all `RangeSlider` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const RangeSliderPropsContext: React_2.Context<(p: RangeSliderProps) => RangeSliderProps>;

/**
 * Represents the [KendoReact Rating component]({% slug overview_rating %}).
 *
 * Accepts properties of type [RatingProps]({% slug api_inputs_ratingprops %}).
 * Obtaining the `ref` returns an object of type [RatingHandle]({% slug api_inputs_ratinghandle %}).
 */
export declare const Rating: React_2.ForwardRefExoticComponent<RatingProps & React_2.RefAttributes<RatingHandle | null>>;

/**
 * @hidden
 */
export declare enum RATING_ACTION {
    select = "select",
    deselect = "deselect",
    increase = "increase",
    decrease = "decrease",
    min = "min",
    max = "max",
    reset = "reset"
}

/**
 * @hidden
 */
declare type RatingAction = {
    min: number;
    max: number;
    step?: number;
};

/**
 * @hidden
 */
declare type RatingActionDispatch = {
    type: RATING_ACTION;
    payload?: number;
    event?: React.SyntheticEvent<any>;
};

/**
 * Represents the return type of RatingChangeEvent.
 */
export declare interface RatingChangeEvent {
    /**
     * The current Rating value.
     */
    value: number;
    /**
     * The target of the RatingChangeEvent from RatingHandle.
     */
    target: RatingHandle;
    /**
     * The event of the RatingChangeEvent.
     */
    syntheticEvent: React_2.SyntheticEvent<any>;
}

/**
 * Represents the return type od the RatingFocusEvent.
 */
export declare interface RatingFocusEvent {
    /**
     * The target of the RatingFocusEvent from RatingHandle.
     */
    target: RatingHandle;
    /**
     * The event of the RatingFocusEvent.
     */
    syntheticEvent: React.FocusEvent<any>;
}

/**
 * Represents the target(element and props) of the RatingChangeEvent.
 */
export declare interface RatingHandle {
    /**
     * The current element or `null` if there is no one.
     */
    element: HTMLDivElement | null;
    /**
     * The props value of the Rating.
     */
    props: RatingProps;
}

/**
 * Represents the RatingItem component.
 */
export declare const RatingItem: React_2.ForwardRefExoticComponent<RatingItemProps & React_2.RefAttributes<RatingItemHandle | null>>;

/**
 * Represents the return type of the RatingItemFocusEvent.
 */
export declare interface RatingItemFocusEvent {
    /**
     * The target of the RatingItemFocusEvent from RatingItemHandle.
     */
    target: RatingItemHandle;
    /**
     * The event of the RatingItemFocusEvent.
     */
    syntheticEvent: React.FocusEvent<any>;
}

/**
 * Represents the target(value, element and props) of The RatingItem.
 */
export declare interface RatingItemHandle {
    /**
     * The current RatingItem value.
     */
    value: number;
    /**
     * The current element or `null` if there is no one.
     */
    element: HTMLDivElement | null;
    /**
     * The props value of the RatingItem.
     */
    props: RatingItemProps;
}

/**
 * Represents the return type of the RatingItemKeyboardEvent.
 */
export declare interface RatingItemKeyboardEvent {
    /**
     * The target of the RatingItemKeyboardEvent from RatingItemHandle.
     */
    target: RatingItemHandle;
    /**
     * The event of the RatingItemKeyboardEvent.
     */
    syntheticEvent: React.KeyboardEvent<any>;
}

/**
 * Represents the return type of the RatingItemMouseEvent.
 */
export declare interface RatingItemMouseEvent {
    /**
     * The target of the RatingItemMouseEvent from RatingItemHandle.
     */
    target: RatingItemHandle;
    /**
     * The event of the RatingItemMouseEvent.
     */
    syntheticEvent: React.MouseEvent<any>;
    /**
     * @hidden
     */
    value?: number | null;
}

/**
 * Represents the properties of [RatingItem](% slug api_inputs_ratingitem %) component.
 */
export declare interface RatingItemProps {
    /**
     * Sets the `id` property of the top div element of the RatingItem.
     */
    id?: string;
    /**
     * Sets additional classes to the RatingItem.
     */
    className?: string;
    /**
     * Sets the `tabIndex` attribute.
     */
    tabIndex?: number;
    /**
     * Determines if icon is partly selected.
     */
    half?: boolean;
    /**
     * Sets additional CSS styles to the RatingItem.
     */
    style?: React_2.CSSProperties;
    /**
     * Determines the children nodes.
     */
    children?: React_2.ReactNode;
    /**
     * Determines the RatingItem direction `ltr` - by default, or `rtl`.
     */
    dir?: string;
    /**
     * Sets the current value of the RatingItem, used in controlled mode.
     */
    value: number;
    /**
     * Sets the title of current RatingItem component. [See example]({% slug controlled_rating %})
     */
    title?: string;
    /**
     * Sets the icon of current RatingItem component. [See example]({% slug label_rating %})
     */
    icon?: any;
    /**
     * Determines if current RatingItem is selected. [See example]({% slug item_customization_ratingitem %})
     */
    selected?: boolean;
    /**
     * Determines if current RatingItem is hovered.
     */
    hovered?: boolean;
    /**
     * Triggered after `onClick` event. Gets outside access to the target element, the new value and the event type.
     */
    onClick?: (event: RatingItemMouseEvent) => void;
    /**
     * Triggered after `onKeyDown` event. Gets outside access to the target element, the new value and the event type.
     */
    onKeyDown?: (event: RatingItemKeyboardEvent) => void;
    /**
     * Triggered after `onFocus` event. Gets outside access to the target element and the event type.
     */
    onFocus?: (event: RatingItemFocusEvent) => void;
    /**
     * Triggered after `onBlur` event. Gets outside access to the target element and the event type.
     */
    onBlur?: (event: RatingItemFocusEvent) => void;
    /**
     * Triggered after `onMouseEnter` event. Gets outside access to the target element and the event type.
     */
    onMouseEnter?: (event: RatingItemMouseEvent) => void;
    /**
     * Triggered after `onMouseLeave` event. Gets outside access to the target element and the event type.
     */
    onMouseLeave?: (event: RatingItemMouseEvent) => void;
    /**
     * Triggered after `onMouseMove` event. Gets outside access to the target element and the event type.
     */
    onMouseMove?: (event: RatingItemMouseEvent) => void;
}

/**
 * Represents the return type of the RatingKeyboardEvent.
 */
export declare interface RatingKeyboardEvent {
    /**
     * The target of the RatingKeyboardEvent from RatingHandle.
     */
    target: RatingHandle;
    /**
     * The event of the RatingKeyboardEvent.
     */
    syntheticEvent: React.KeyboardEvent<any>;
}

/**
 * Represents the return type of the RatingMouseEvent.
 */
export declare interface RatingMouseEvent {
    /**
     * The target of the RatingMouseEvent from RatingHandle.
     */
    target: RatingHandle;
    /**
     * The event of the RatingMouseEvent.
     */
    syntheticEvent: React.MouseEvent<any>;
}

/**
 * Represents the properties of [Rating](% slug api_inputs_rating %) component.
 */
export declare interface RatingProps extends FormComponentProps {
    /**
     * Sets the `id` property of the top div element of the Rating.
     *
     * @example
     * ```jsx
     * <Rating id="rating-component" value={3} />
     * ```
     */
    id?: string;
    /**
     * Adds custom CSS classes to the Rating.
     *
     * @example
     * ```jsx
     * <Rating className="custom-class" value={4} />
     * ```
     */
    className?: string;
    /**
     * Sets the `tabIndex` attribute.
     *
     * @example
     * ```jsx
     * <Rating tabIndex={0} value={2} />
     * ```
     */
    tabIndex?: number;
    /**
     * Sets additional CSS styles to the Rating.
     *
     * @example
     * ```jsx
     * <Rating style={{ margin: '10px' }} value={5} />
     * ```
     */
    style?: React_2.CSSProperties;
    /**
     * Determines the children nodes.
     *
     * @example
     * ```jsx
     * <Rating>
     *   <span>Custom Child</span>
     * </Rating>
     * ```
     */
    children?: React_2.ReactNode;
    /**
     * Represents the rendered Rating item.
     *
     * @example
     * ```jsx
     * <Rating item={(props) => <div>{props.value}</div>} />
     * ```
     */
    item?: React_2.ComponentType<RatingItemProps>;
    /**
     * Sets the current value of the Rating, used in controlled mode.
     *
     * @example
     * ```jsx
     * <Rating value={3} />
     * ```
     */
    value?: number;
    /**
     * Sets the default value of the Rating, used in uncontrolled mode.
     *
     * @example
     * ```jsx
     * <Rating defaultValue={2} />
     * ```
     */
    defaultValue?: number;
    /**
     * Sets the minimum possible value of the Rating.
     *
     * @example
     * ```jsx
     * <Rating min={1} max={10} />
     * ```
     */
    min?: number;
    /**
     * Sets the maximum possible value of the Rating.
     *
     * @example
     * ```jsx
     * <Rating max={10} />
     * ```
     */
    max?: number;
    /**
     * Sets the step value between the minimum and maximum values.
     *
     * @example
     * ```jsx
     * <Rating step={0.5} />
     * ```
     */
    step?: number;
    /**
     * Specifies the direction of the Rating (`ltr` or `rtl`).
     *
     * @example
     * ```jsx
     * <Rating dir="rtl" />
     * ```
     */
    dir?: string;
    /**
     * Sets a custom label for the Rating.
     *
     * @example
     * ```jsx
     * <Rating label="Rating Label" />
     * ```
     */
    label?: React_2.ReactNode;
    /**
     * Sets the `readonly` mode of the Rating.
     *
     * @example
     * ```jsx
     * <Rating readonly={true} value={4} />
     * ```
     */
    readonly?: boolean;
    /**
     * Disables the Rating when set to `true`.
     *
     * @example
     * ```jsx
     * <Rating disabled={true} />
     * ```
     */
    disabled?: boolean;
    /**
     * Sets a custom icon for the Rating.
     *
     * @example
     * ```jsx
     * <Rating icon="star" />
     * ```
     */
    icon?: string;
    /**
     * Sets a custom SVG icon for the Rating.
     *
     * @example
     * ```jsx
     * import { gearIcon } from '@progress/kendo-svg-icons';
     *
     * <Rating svgIcon={gearIcon} />
     * ```
     */
    svgIcon?: SVGIcon;
    /**
     * Sets a custom outline SVG icon for the Rating.
     *
     * @example
     * ```jsx
     * <Rating svgIconOutline={customOutlineSvgIcon} />
     * ```
     */
    svgIconOutline?: SVGIcon;
    /**
     * Determines the selection mode of the Rating (`continues` or `single`).
     *
     * @example
     * ```jsx
     * <Rating selection="single" />
     * ```
     */
    selection?: 'continues' | 'single';
    /**
     * Determines the precision of the Rating (`item` or `half`).
     *
     * @example
     * ```jsx
     * <Rating precision="half" />
     * ```
     */
    precision?: 'half' | 'item';
    /**
     * Determines if the value represents a half icon (`true`) or not (`false`).
     *
     * @example
     * ```jsx
     * <Rating half={true} />
     * ```
     */
    half?: boolean;
    /**
     * Fires when the value of the Rating changes.
     *
     * @example
     * ```jsx
     * <Rating onChange={(event) => console.log(event.value)} />
     * ```
     */
    onChange?: (event: RatingChangeEvent) => void;
    /**
     * Fires when the Rating is clicked.
     *
     * @example
     * ```jsx
     * <Rating onClick={(event) => console.log(event.value)} />
     * ```
     */
    onClick?: (event: RatingItemMouseEvent) => void;
    /**
     * Fires when a key is pressed while the Rating is focused.
     *
     * @example
     * ```jsx
     * <Rating onKeyDown={(event) => console.log(event.value)} />
     * ```
     */
    onKeyDown?: (event: RatingKeyboardEvent) => void;
    /**
     * Fires when the Rating is focused.
     *
     * @example
     * ```jsx
     * <Rating onFocus={(event) => console.log('Focused')} />
     * ```
     */
    onFocus?: (event: RatingItemFocusEvent) => void;
    /**
     * Fires when the Rating loses focus.
     *
     * @example
     * ```jsx
     * <Rating onBlur={(event) => console.log('Blurred')} />
     * ```
     */
    onBlur?: (event: RatingItemFocusEvent) => void;
    /**
     * Identifies the element(s) which will describe the component.
     *
     * @example
     * ```jsx
     * <Rating ariaDescribedBy="description-id" />
     * ```
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     *
     * @example
     * ```jsx
     * <Rating ariaLabelledBy="label-id" />
     * ```
     */
    ariaLabelledBy?: string;
}

/**
 * Represents the PropsContext of the `Rating` component.
 * Used for global configuration of all `Rating` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const RatingPropsContext: React_2.Context<(p: RatingProps) => RatingProps>;

/**
 * @hidden
 */
export declare const ratingReducer: (state: any, action: RatingAction & RatingActionDispatch) => any;

/**
 * @hidden
 */
declare interface RGBA {
    r?: number;
    g?: number;
    b?: number;
    a?: number;
}

/**
 * @hidden
 */
export declare const sanitizeNumber: (state: NumericTextBoxState, format: string | NumberFormatOptions | undefined, intlService: any) => NumericTextBoxState;

/**
 * Represents the [KendoReact Signature component]({% slug overview_signature %}).
 */
export declare const Signature: React_2.ForwardRefExoticComponent<SignatureProps & React_2.RefAttributes<SignatureHandle | null>>;

/**
 * The arguments for the `onBlur` Signature event.
 */
export declare interface SignatureBlurEvent extends BaseEvent<SignatureHandle> {
}

/**
 * The arguments for the `change` event of the Signature.
 */
export declare interface SignatureChangeEvent extends BaseEvent<SignatureHandle> {
    /**
     * The current value of the Signature.
     */
    value: string;
}

/**
 * The arguments for the `onClose` Signature event.
 */
export declare interface SignatureCloseEvent extends BaseEvent<SignatureHandle> {
}

/**
 * The arguments for the `onFocus` Signature event.
 */
export declare interface SignatureFocusEvent extends BaseEvent<SignatureHandle> {
}

/**
 * The Signature ref.
 */
export declare interface SignatureHandle {
    /**
     * The Signature element.
     */
    element: HTMLInputElement | null;
    /**
     * Focus the Signature.
     */
    focus: () => void;
    /**
     * Gets the `name` property of the Signature.
     */
    name: string | undefined;
    /**
     * Gets the value of the Signature.
     */
    value: number | null;
    /**
     * @hidden
     */
    props: SignatureProps;
    /**
     * @hidden
     */
    validityStyles: boolean;
    /**
     * @hidden
     */
    required: boolean;
    /**
     * @hidden
     */
    color: string;
    /**
     * @hidden
     */
    backgroundColor: string;
}

/**
 * The arguments for the `onOpen` Signature event.
 */
export declare interface SignatureOpenEvent extends BaseEvent<SignatureHandle> {
}

/**
 * Represents the props of the [KendoReact Signature component]({% slug overview_signature %}).
 */
export declare interface SignatureProps extends FormComponentProps {
    /**
     * Adds custom CSS classes to the Signature.
     *
     * @example
     * ```jsx
     * <Signature className="custom-class" />
     * ```
     */
    className?: string;
    /**
     * Specifies the value of the Signature as a Data URL.
     *
     * @example
     * ```jsx
     * <Signature value="data:image/png;base64,..." />
     * ```
     */
    value?: string;
    /**
     * Specifies the width of the Signature in pixels.
     *
     * @example
     * ```jsx
     * <Signature width={500} />
     * ```
     */
    width?: number;
    /**
     * Specifies the height of the Signature in pixels.
     *
     * @example
     * ```jsx
     * <Signature height={300} />
     * ```
     */
    height?: number;
    /**
     * Specifies the `tabIndex` of the Signature.
     *
     * @example
     * ```jsx
     * <Signature tabIndex={0} />
     * ```
     */
    tabIndex?: number;
    /**
     * Specifies the `id` of the Signature.
     *
     * @example
     * ```jsx
     * <Signature id="signature-component" />
     * ```
     */
    id?: string;
    /**
     * Represents the `dir` HTML attribute.
     *
     * @example
     * ```jsx
     * <Signature dir="rtl" />
     * ```
     */
    dir?: string;
    /**
     * Specifies the name of the Signature input.
     *
     * @example
     * ```jsx
     * <Signature name="signature" />
     * ```
     */
    name?: string;
    /**
     * Identifies the element(s) which will describe the component.
     *
     * @example
     * ```jsx
     * <Signature ariaDescribedBy="description-id" />
     * ```
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     *
     * @example
     * ```jsx
     * <Signature ariaLabelledBy="label-id" />
     * ```
     */
    ariaLabelledBy?: string;
    /**
     * Specifies the accessible label of the Signature.
     *
     * @example
     * ```jsx
     * <Signature ariaLabel="Signature field" />
     * ```
     */
    ariaLabel?: string;
    /**
     * Sets the Signature to read-only mode.
     *
     * @example
     * ```jsx
     * <Signature readOnly={true} />
     * ```
     */
    readOnly?: boolean;
    /**
     * Disables the Signature when set to `true`.
     *
     * @example
     * ```jsx
     * <Signature disabled={true} />
     * ```
     */
    disabled?: boolean;
    /**
     * Configures the size of the Signature.
     *
     * @example
     * ```jsx
     * <Signature size="large" />
     * ```
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the roundness of the Signature.
     *
     * @example
     * ```jsx
     * <Signature rounded="medium" />
     * ```
     */
    rounded?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the fill mode of the Signature.
     *
     * @example
     * ```jsx
     * <Signature fillMode="solid" />
     * ```
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * Specifies the stroke color of the Signature.
     *
     * @example
     * ```jsx
     * <Signature color="blue" />
     * ```
     */
    color?: string;
    /**
     * Specifies the background color of the Signature.
     *
     * @example
     * ```jsx
     * <Signature backgroundColor="lightgray" />
     * ```
     */
    backgroundColor?: string;
    /**
     * Specifies the stroke width of the Signature.
     *
     * @example
     * ```jsx
     * <Signature strokeWidth={2} />
     * ```
     */
    strokeWidth?: number;
    /**
     * Enables smoothing of the signature lines.
     *
     * @example
     * ```jsx
     * <Signature smooth={true} />
     * ```
     */
    smooth?: boolean;
    /**
     * Enables the maximizable feature of the Signature.
     *
     * @example
     * ```jsx
     * <Signature maximizable={true} />
     * ```
     */
    maximizable?: boolean;
    /**
     * Sets the open state of the Signature popup.
     *
     * @example
     * ```jsx
     * <Signature open={true} />
     * ```
     */
    open?: boolean;
    /**
     * The scale factor for the popup.
     *
     * The Signature width and height will be multiplied by the scale when showing the popup.
     *
     * @default 3
     * @example
     * ```jsx
     * <Signature popupScale={1.5} />
     * ```
     */
    popupScale?: number;
    /**
     * The scale factor for the exported image.
     *
     * The Signature width and height will be multiplied by the scale when converting the signature to an image.
     *
     * @default 2
     *
     * @example
     * ```jsx
     * <Signature exportScale={2} />
     * ```
     */
    exportScale?: number;
    /**
     * Hides the dotted line in the background.
     *
     * @default false
     * @example
     * ```jsx
     * <Signature hideLine={true} />
     * ```
     */
    hideLine?: boolean;
    /**
     * Represents the `style` HTML attribute.
     *
     * @example
     * ```jsx
     * <Signature style={{ border: '1px solid black' }} />
     * ```
     */
    style?: React.CSSProperties;
    /**
     * Represents the input element `style` HTML attribute.
     *
     * @example
     * ```jsx
     * <Signature inputStyle={{ padding: '10px' }} />
     * ```
     */
    inputStyle?: React.CSSProperties;
    /**
     * Fires when the value of the Signature changes.
     *
     * @example
     * ```jsx
     * <Signature onChange={(event) => console.log(event.value)} />
     * ```
     */
    onChange?: (event: SignatureChangeEvent) => void;
    /**
     * Fires when the Signature is focused.
     *
     * @example
     * ```jsx
     * <Signature onFocus={(event) => console.log('Focused')} />
     * ```
     */
    onFocus?: (event: SignatureFocusEvent) => void;
    /**
     * Fires when the Signature is blurred.
     *
     * @example
     * ```jsx
     * <Signature onBlur={(event) => console.log('Blurred')} />
     * ```
     */
    onBlur?: (event: SignatureBlurEvent) => void;
    /**
     * Fires when the Signature popup is opened.
     *
     * @example
     * ```jsx
     * <Signature onOpen={(event) => console.log('Popup opened')} />
     * ```
     */
    onOpen?: (event: SignatureOpenEvent) => void;
    /**
     * Fires when the Signature popup is closed.
     *
     * @example
     * ```jsx
     * <Signature onClose={(event) => console.log('Popup closed')} />
     * ```
     */
    onClose?: (event: SignatureCloseEvent) => void;
    /** @hidden */
    children?: React.ReactNode;
    /** @hidden */
    maximized?: boolean;
}

/**
 * Represents the PropsContext of the `Signature` component.
 * Used for global configuration of all `Signature` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const SignaturePropsContext: React_2.Context<(p: SignatureProps) => SignatureProps>;

/** @hidden */
export declare type Slider = SliderHandle;

/**
 * Represents the [KendoReact Slider component]({% slug overview_slider %}).
 *
 * Accepts properties of type [SliderProps]({% slug api_inputs_sliderprops %}).
 * Obtaining the `ref` returns an object of type [SliderHandle]({% slug api_inputs_sliderhandle %}).
 */
export declare const Slider: React_2.ForwardRefExoticComponent<SliderProps & React_2.RefAttributes<any>>;

/**
 * @hidden
 */
export declare const SLIDER_LABEL_ATTRIBUTE = "data-slider-label";

/**
 * The arguments for the `onChange` Slider event.
 */
export declare interface SliderChangeEvent extends BaseEvent<Slider> {
    /**
     * The current value of the Slider.
     */
    value: number;
}

/**
 * Represent the `ref` of the Slider component.
 *
 * @remarks
 * Supported children components are: {@link SliderLabel}.
 */
export declare interface SliderHandle extends Pick<SliderWithoutContext, keyof SliderWithoutContext> {
}

/**
 * Represents the KendoReact SliderLabel component.
 */
export declare const SliderLabel: (props: SliderLabelProps) => JSX.Element;

/**
 * Represents the props of the KendoReact SliderLabel component.
 */
export declare interface SliderLabelProps {
    /**
     * The position in relative to the start of the SliderLabel component.
     */
    position: number;
    /**
     * The onClick event of the SliderLabel component.
     */
    onClick?: (event: React_2.MouseEvent<HTMLLIElement>) => void;
    /**
     * The title of the SliderLabel component.
     */
    title?: string;
    /**
     * @hidden
     */
    children?: React_2.ReactNode;
    /**
     * @hidden
     */
    vertical?: boolean;
    /**
     * @hidden
     * Used to identify if a tick is first.
     */
    firstTick?: boolean;
    /**
     * @hidden
     * Used to identify if a tick is last.
     */
    lastTick?: boolean;
}

/**
 * Represents the props of the [KendoReact Slider component]({% slug overview_slider %}).
 */
export declare interface SliderProps extends FormComponentProps {
    children?: React_2.ReactNode;
    /**
     * Specifies the current value of the Slider.
     *
     * @example
     * ```jsx
     * <Slider value={50} min={0} max={100} />
     * ```
     */
    value?: number;
    /**
     * Specifies the default value of the Slider.
     *
     * @example
     * ```jsx
     * <Slider defaultValue={30} min={0} max={100} />
     * ```
     */
    defaultValue?: number;
    /**
     * Specifies the minimum value of the Slider.
     *
     * @example
     * ```jsx
     * <Slider min={0} max={100} />
     * ```
     */
    min: number;
    /**
     * Specifies the maximum value of the Slider.
     *
     * @example
     * ```jsx
     * <Slider min={0} max={100} />
     * ```
     */
    max: number;
    /**
     * Specifies the step by which the Slider's value will be increased or decreased using its buttons or keyboard arrows.
     *
     * @example
     * ```jsx
     * <Slider step={5} min={0} max={100} />
     * ```
     */
    step?: number;
    /**
     * Specifies the step by which the Slider's value will be increased or decreased using `pageUp` or `pageDown` keyboard buttons.
     *
     * @example
     * ```jsx
     * <Slider largeStep={10} min={0} max={100} />
     * ```
     */
    largeStep?: number;
    /**
     * Fires when the value of the Slider changes.
     *
     * @example
     * ```jsx
     * <Slider onChange={(event) => console.log(event.value)} min={0} max={100} />
     * ```
     */
    onChange?: (event: SliderChangeEvent) => void;
    /**
     * Sets additional CSS styles to the Slider.
     *
     * @example
     * ```jsx
     * <Slider style={{ margin: '10px' }} min={0} max={100} />
     * ```
     */
    style?: React_2.CSSProperties;
    /**
     * Adds custom CSS classes to the Slider.
     *
     * @example
     * ```jsx
     * <Slider className="custom-class" min={0} max={100} />
     * ```
     */
    className?: string;
    /**
     * Renders the arrow side buttons of the Slider if set to `true`.
     *
     * @example
     * ```jsx
     * <Slider buttons={true} min={0} max={100} />
     * ```
     */
    buttons?: boolean;
    /**
     * Specifies the `tabIndex` of the Slider.
     *
     * @example
     * ```jsx
     * <Slider tabIndex={0} min={0} max={100} />
     * ```
     */
    tabIndex?: number;
    /**
     * When `true`, disables the Slider.
     *
     * @example
     * ```jsx
     * <Slider disabled={true} min={0} max={100} />
     * ```
     */
    disabled?: boolean;
    /**
     * Changes the orientation of the Slider to vertical if set to `true`.
     *
     * @example
     * ```jsx
     * <Slider vertical={true} min={0} max={100} />
     * ```
     */
    vertical?: boolean;
    /**
     * Specifies the `id` of the Slider.
     *
     * @example
     * ```jsx
     * <Slider id="slider-component" min={0} max={100} />
     * ```
     */
    id?: string;
    /**
     * Identifies the element(s) which will describe the component.
     *
     * @example
     * ```jsx
     * <Slider ariaDescribedBy="description-id" min={0} max={100} />
     * ```
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     *
     * @example
     * ```jsx
     * <Slider ariaLabelledBy="label-id" min={0} max={100} />
     * ```
     */
    ariaLabelledBy?: string;
    /**
     * Specifies the accessible label of the Slider.
     *
     * @example
     * ```jsx
     * <Slider ariaLabel="Slider component" min={0} max={100} />
     * ```
     */
    ariaLabel?: string;
    /**
     * Specifies the direction of the Slider (`ltr` or `rtl`).
     *
     * @example
     * ```jsx
     * <Slider dir="rtl" min={0} max={100} />
     * ```
     */
    dir?: Direction;
}

/**
 * Represents the PropsContext of the `Slider` component.
 * Used for global configuration of all `Slider` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const SliderPropsContext: React_2.Context<(p: SliderProps) => SliderProps>;

/**
 * @hidden
 */
declare interface SliderState {
    value: number;
    focused: boolean;
    dir?: Direction;
}

/** @hidden */
export declare class SliderWithoutContext extends React_2.Component<SliderProps, SliderState> {
    static displayName: string;
    /**
     * @hidden
     */
    static propTypes: {
        min: default_2.Validator<number>;
        max: default_2.Validator<number>;
        value: default_2.Requireable<number>;
        vertical: default_2.Requireable<boolean>;
        id: default_2.Requireable<string>;
        ariaLabelledBy: default_2.Requireable<string>;
        ariaDescribedBy: default_2.Requireable<string>;
        ariaLabel: default_2.Requireable<string>;
    };
    /**
     * @hidden
     */
    static getDerivedStateFromProps(props: SliderProps, state: SliderState): {
        value: number;
    } | null;
    /**
     * @hidden
     */
    state: {
        value: number;
        focused: boolean;
        dir: Direction | undefined;
    };
    private _sliderTrack;
    private _element;
    constructor(props: SliderProps);
    /**
     * @hidden
     */
    componentDidMount(): void;
    /**
     * @hidden
     */
    buttons: (props: any) => any;
    /**
     * @hidden
     */
    render(): JSX.Element;
    /**
     * @hidden
     */
    focus: () => void;
    /**
     * @hidden
     */
    get sliderTrack(): HTMLDivElement | null;
    private isLabel;
    private onFocus;
    private onBlur;
    private onKeyDown;
    private decrement;
    private increment;
    private dragStart;
    private dragOver;
    private drag;
    private change;
}

/** @hidden */
export declare type Switch = SwitchHandle;

/**
 * Represents the [KendoReact Switch component]({% slug overview_switch %}).
 *
 * Accepts properties of type [SwitchProps]({% slug api_inputs_switchprops %}).
 * Obtaining the `ref` returns an object of type [SwitchHandle]({% slug api_inputs_switchhandle %}).
 */
export declare const Switch: React_2.ForwardRefExoticComponent<SwitchProps & React_2.RefAttributes<any>>;

/**
 * The arguments for the `onChange` Switch event.
 */
export declare interface SwitchChangeEvent extends BaseEvent<Switch> {
    /**
     * The new value of the Switch.
     */
    value: boolean;
}

/**
 * Represent the `ref` of the Switch component.
 */
export declare interface SwitchHandle extends Pick<SwitchWithoutContext, keyof SwitchWithoutContext> {
    /**
     * @hidden
     */
    actionElement: HTMLSpanElement | null;
    /**
     * Returns the HTML element of the Switch component.
     */
    element: HTMLSpanElement | null;
    /**
     * Gets the `name` property of the Switch.
     */
    name: string | undefined;
    /**
     * Represents the validity state into which the Switch is set.
     */
    validity: FormComponentValidity;
    /**
     * Gets the value of the Switch.
     */
    value: boolean;
}

/**
 * Represents the props of the [KendoReact Switch component]({% slug overview_switch %}).
 */
export declare interface SwitchProps extends ToggleBaseProps, FormComponentProps {
    /**
     * Specifies the `accessKey` of the Switch.
     *
     * @example
     * ```jsx
     * <Switch accessKey="s" />
     * ```
     */
    accessKey?: string;
    /**
     * Sets the current value of the Switch ([see example]({% slug controlled_switch %})).
     *
     * @example
     * ```jsx
     * <Switch checked={true} />
     * ```
     */
    checked?: boolean;
    /**
     * Adds custom CSS classes to the Switch.
     *
     * @example
     * ```jsx
     * <Switch className="custom-class" />
     * ```
     */
    className?: string;
    /**
     * Sets the value of the Switch when it is initially displayed ([see example]({% slug default_state %})).
     *
     * @example
     * ```jsx
     * <Switch defaultChecked={true} />
     * ```
     */
    defaultChecked?: boolean;
    /**
     * Specifies the default value of the Switch.
     *
     * @example
     * ```jsx
     * <Switch defaultValue={true} />
     * ```
     */
    defaultValue?: any;
    /**
     * Disables the Switch when set to `true` ([see example]({% slug disabled_switch %})).
     *
     * @example
     * ```jsx
     * <Switch disabled={true} />
     * ```
     */
    disabled?: boolean;
    /**
     * Specifies the `dir` property of the wrapping element of the Switch.
     *
     * @example
     * ```jsx
     * <Switch dir="rtl" />
     * ```
     */
    dir?: string;
    /**
     * Specifies the `id` of the Switch.
     *
     * @example
     * ```jsx
     * <Switch id="switch-component" />
     * ```
     */
    id?: string;
    /**
     * Configures the `size` of the Switch.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     * @example
     * ```jsx
     * <Switch size="large" />
     * ```
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `trackRounded` of the Switch.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a trackRounded `className`.
     *
     * @default `full`
     * @example
     * ```jsx
     * <Switch trackRounded="medium" />
     * ```
     */
    trackRounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Configures the `thumbRounded` property of the Switch.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a thumbRounded `className`.
     *
     * @example
     * ```jsx
     * <Switch thumbRounded="full" />
     * ```
     */
    thumbRounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Identifies the element(s) which will describe the component.
     * For example these elements could contain error or hint message.
     *
     * @example
     * ```jsx
     * <Switch ariaDescribedBy="description-id" />
     * ```
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     *
     * @example
     * ```jsx
     * <Switch ariaLabelledBy="label-id" />
     * ```
     */
    ariaLabelledBy?: string;
    /**
     * Sets a custom label for the **Off** state.
     *
     * @example
     * ```jsx
     * <Switch offLabel="No" />
     * ```
     */
    offLabel?: React_2.ReactNode;
    /**
     * Fires when the Switch is blurred.
     *
     * @example
     * ```jsx
     * <Switch onBlur={(event) => console.log('Blurred')} />
     * ```
     */
    onBlur?: (event: React_2.FocusEvent<HTMLSpanElement>) => void;
    /**
     * Fires when the value of the Switch changes.
     *
     * @example
     * ```jsx
     * <Switch onChange={(event) => console.log(event.value)} />
     * ```
     */
    onChange?: (event: SwitchChangeEvent) => void;
    /**
     * Fires when the Switch is focused.
     *
     * @example
     * ```jsx
     * <Switch onFocus={(event) => console.log('Focused')} />
     * ```
     */
    onFocus?: (event: React_2.FocusEvent<HTMLSpanElement>) => void;
    /**
     * Sets a custom label for the **On** state.
     *
     * @example
     * ```jsx
     * <Switch onLabel="Yes" />
     * ```
     */
    onLabel?: React_2.ReactNode;
    /**
     * Specifies the [`tabIndex`](https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/tabindex) of the component.
     *
     * @example
     * ```jsx
     * <Switch tabIndex={0} />
     * ```
     */
    tabIndex?: number;
    /**
     * Specifies the value of the Switch.
     *
     * @example
     * ```jsx
     * <Switch value={true} />
     * ```
     */
    value?: string | number | string[] | boolean | null;
    /**
     * Specifies the accessible label of the Switch.
     *
     * @example
     * ```jsx
     * <Switch ariaLabel="Toggle switch" />
     * ```
     */
    ariaLabel?: string;
}

/**
 * Represents the PropsContext of the `Switch` component.
 * Used for global configuration of all `Switch` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const SwitchPropsContext: React_2.Context<(p: SwitchProps) => SwitchProps>;

/**
 * @hidden
 */
export declare interface SwitchState {
    checked: boolean;
    focused: boolean;
}

/** @hidden */
export declare class SwitchWithoutContext extends React_2.Component<SwitchProps, SwitchState> implements FormComponent {
    static displayName: string;
    /**
     * Gets the value of the Switch.
     */
    get value(): boolean;
    get element(): HTMLSpanElement | null;
    get actionElement(): HTMLSpanElement | null;
    /**
     * Gets the `name` property of the Switch.
     */
    get name(): string | undefined;
    /**
     * Represents the validity state into which the Switch is set.
     */
    get validity(): FormComponentValidity;
    /**
     * @hidden
     */
    protected get validityStyles(): boolean;
    /**
     * @hidden
     */
    protected get required(): boolean;
    /**
     * @hidden
     */
    protected setValidity: () => void;
    protected limit: (offset: number, drag: HTMLSpanElement, wrapper: HTMLSpanElement) => number;
    protected toggle: (value: boolean, event: any) => void;
    /**
     * @hidden
     */
    static propTypes: {
        accessKey: default_2.Requireable<string>;
        checked: default_2.Requireable<boolean>;
        className: default_2.Requireable<string>;
        disabled: default_2.Requireable<boolean>;
        defaultChecked: default_2.Requireable<boolean>;
        size: default_2.Requireable<"small" | "large" | "medium" | null | undefined>;
        trackRounded: default_2.Requireable<"small" | "large" | "medium" | "full" | null | undefined>;
        thumbRounded: default_2.Requireable<"small" | "large" | "medium" | "full" | null | undefined>;
        dir: default_2.Requireable<string>;
        id: default_2.Requireable<string>;
        ariaLabelledBy: default_2.Requireable<string>;
        ariaDescribedBy: default_2.Requireable<string>;
        offLabel: default_2.Requireable<string>;
        required: default_2.Requireable<boolean>;
        tabIndex: default_2.Requireable<number>;
        valid: default_2.Requireable<boolean>;
        validate: default_2.Requireable<boolean>;
        validationMessage: default_2.Requireable<string>;
        onBlur: default_2.Requireable<any>;
        onChange: default_2.Requireable<any>;
        onFocus: default_2.Requireable<any>;
        onLabel: default_2.Requireable<string>;
    };
    /**
     * @hidden
     */
    static defaultProps: {
        disabled: boolean;
        defaultChecked: boolean;
        size: "small" | "large" | "medium" | null | undefined;
        trackRounded: "small" | "large" | "medium" | "full" | null | undefined;
        thumbRounded: "small" | "large" | "medium" | "full" | null | undefined;
        offLabel: string;
        onBlur: () => void;
        onFocus: () => void;
        onLabel: string;
        validityStyles: boolean;
    };
    /**
     * @hidden
     */
    readonly state: SwitchState;
    private _element;
    private _wrapper;
    private _input;
    private _id;
    private valueDuringOnChange;
    private dir?;
    private defaultValidationMessage;
    private eventTimeStamp?;
    /**
     * @hidden
     */
    constructor(props: SwitchProps);
    /**
     * @hidden
     */
    componentDidMount(): void;
    /**
     * @hidden
     */
    componentDidUpdate(): void;
    /**
     * @hidden
     */
    focus: () => void;
    /**
     * @hidden
     */
    render(): JSX.Element;
    private dummyInput;
    private handleClick;
    private handleKeyDown;
    private handleWrapperFocus;
    private handleWrapperBlur;
}

/**
 * Represents the [KendoReact TextArea component]({% slug overview_textarea %}).
 *
 *
 * Accepts properties of type [TextAreaProps]({% slug api_inputs_textareaprops %}).
 *
 * @example
 * ```jsx
 * class App extends React.Component {
 *     render() {
 *         return <TextArea />;
 *     }
 * }
 * ReactDOM.render(<App />, document.querySelector('my-app'));
 * ```
 */
export declare const TextArea: React_2.ForwardRefExoticComponent<TextAreaProps & React_2.RefAttributes<TextAreaHandle | null>>;

/**
 * The arguments for the `onBlur` TextArea event.
 */
export declare interface TextAreaBlurEvent extends BaseEvent<TextAreaHandle> {
}

/**
 * The arguments for the `onChange` TextArea event.
 */
export declare interface TextAreaChangeEvent extends BaseEvent<TextAreaHandle> {
    /**
     * The new value of the TextArea.
     */
    value: string;
}

/**
 * The arguments for the `onFocus` TextArea event.
 */
export declare interface TextAreaFocusEvent extends BaseEvent<TextAreaHandle> {
}

/**
 * @hidden
 */
export declare interface TextAreaHandle {
    element: React_2.RefObject<HTMLTextAreaElement | null>;
    focus: any;
    name?: string | null;
    value?: string;
}

/**
 * Represents the props of the [KendoReact TextArea component]({% slug overview_textarea %}).
 */
export declare interface TextAreaProps extends FormComponentProps, Omit_5<React.TextareaHTMLAttributes<HTMLTextAreaElement>, 'defaultValue' | 'onChange' | 'onFocus' | 'onBlur' | 'prefix'> {
    /**
     * Identifies the element(s) which will describe the component, similar to [HTML aria-describedby attribute](https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/ARIA_Techniques/Using_the_aria-describedby_attribute).
     * For example these elements could contain error or hint message.
     */
    ariaDescribedBy?: string;
    /**
     * Identifies the element(s) which will label the component.
     */
    ariaLabelledBy?: string;
    /**
     * Specifies if the textarea element will resize its height automatically ([see example]({% slug sizing_textarea %})).
     * Defaults to `false`.
     *
     * Setting the value of the prop to `true` will make the TextArea component to ignore the resize behavior of the `resizable` prop.
     */
    autoSize?: boolean;
    /**
     * Specifies a list of CSS classes that will be added to the TextArea.
     */
    className?: string;
    /**
     * The default value of the TextArea ([see example]({% slug default_textarea %})).
     */
    defaultValue?: string | string[] | number;
    /**
     * Represents the `dir` HTML attribute.
     */
    dir?: string;
    /**
     * Specifies if the TextArea is disabled ([see example]({% slug disabled_textarea %})).
     */
    disabled?: boolean;
    /**
     * Sets the read-only state of the TextArea.
     */
    readOnly?: boolean;
    /**
     * Specifies an exact height size for the TextArea to take ([see example]({% slug sizing_textarea %})).
     */
    rows?: number;
    /**
     * Sets the `id` of the TextArea.
     */
    id?: string;
    /**
     * Specifies the `name` property of the `textarea` DOM element.
     *
     * This property is part of the [FormComponentProps]({% slug api_common_formcomponentprops %}) interface.
     */
    name?: string;
    /**
     * The hint that is displayed when the TextArea is empty.
     */
    placeholder?: string;
    /**
     * Sets additional CSS styles to the TextArea.
     */
    style?: React.CSSProperties;
    /**
     * Sets the `tabIndex` property of the TextArea.
     * Defaults to `0`.
     */
    tabIndex?: number;
    /**
     * Sets the value to be submitted ([see example]({% slug controlled_textarea %})).
     */
    value?: string | string[] | number;
    /**
     * The event handler that will be fired when the changes the selected value.
     */
    onChange?: (event: TextAreaChangeEvent) => void;
    /**
     * The event handler that will be fired when TextArea is focused.
     */
    onFocus?: (event: TextAreaFocusEvent) => void;
    /**
     * The event handler that will be fired when TextArea is blurred.
     */
    onBlur?: (event: TextAreaBlurEvent) => void;
    /**
     * Configures the `size` of the TextArea.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `roundness` of the TextArea.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a rounded `className`.
     *
     * @default `medium`
     */
    rounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Configures the `fillMode` of the TextArea.
     *
     * The available options are:
     * - solid
     * - outline
     * - flat
     * - null&mdash;Does not set a fillMode `className`.
     *
     * @default `solid`
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * Sets a custom prefix to the TextArea component.
     */
    prefix?: CustomComponent<any>;
    /**
     * Sets a custom suffix to the TextArea component.
     */
    suffix?: CustomComponent<any>;
    /**
     * Defines the resize behavior of the TextArea.
     * The available options are:
     * - none &mdash; The TextArea cannot be resized.
     * - vertical &mdash; The TextArea can be resized vertically.
     * - horizontal &mdash; The TextArea can be resized horizontally.
     * - both(default) &mdash; The TextArea can be resized both vertically and horizontally.
     *
     *
     * To be able to resize the TextArea, you should not set the `autoSize` property to `true`.
     * To be able to resize the component horizontally, add the following inline style to the TextArea:
     *
     * ```html
     * <TextArea resizable='horizontal' style={{width: 'auto'}}  />
     * ```
     */
    resizable?: 'none' | 'vertical' | 'horizontal' | 'both';
    /**
     * Represents the `autoFocus` HTML attribute that will be applied to the input element of the TextArea. (Defaults to `false`)
     */
    autoFocus?: boolean;
    /**
     * Sets the HTML attributes of the inner focusable input element.
     * Attributes which are essential for certain component functionalities cannot be changed.
     */
    inputAttributes?: React.InputHTMLAttributes<HTMLInputElement>;
}

/**
 * Represents the PropsContext of the `TextArea` component.
 * Used for global configuration of all `TextArea` instances.
 *
 * For more information, refer to the [Inputs Props Context]({% slug props-context_inputs %}) article.
 */
export declare const TextAreaPropsContext: React_2.Context<(p: TextAreaProps) => TextAreaProps>;

/**
 * Represents the [KendoReact TextBox component]({% slug overview_textbox %}).
 */
export declare const TextBox: React_2.ForwardRefExoticComponent<TextBoxProps & React_2.RefAttributes<TextBoxHandle | null>>;

export declare interface TextBoxChangeEvent extends BaseEvent<TextBoxHandle> {
    syntheticEvent: React_2.ChangeEvent<HTMLInputElement>;
    value: React_2.InputHTMLAttributes<HTMLInputElement>['value'];
}

/**
 * Represent the `ref` of the TextBox component.
 */
export declare type TextBoxHandle = {
    element: HTMLInputElement | null;
    value: TextBoxProps['value'];
    name?: string | null;
};

/**
 * Represents the properties of the KendoReact [TextBox]({% slug api_inputs_textbox %}) component
 */
export declare interface TextBoxProps extends Omit<React_2.InputHTMLAttributes<HTMLInputElement>, 'size' | 'prefix' | 'onChange'> {
    /**
     * Configures the `size` of the TextBox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - null&mdash;Does not set a size `className`.
     *
     * @default `medium`
     */
    size?: null | 'small' | 'medium' | 'large';
    /**
     * Configures the `roundness` of the TextBox.
     *
     * The available options are:
     * - small
     * - medium
     * - large
     * - full
     * - null&mdash;Does not set a rounded `className`.
     *
     * @default `medium`
     */
    rounded?: null | 'small' | 'medium' | 'large' | 'full';
    /**
     * Configures the `fillMode` of the TextBox.
     *
     * The available options are:
     * - solid
     * - outline
     * - flat
     * - null&mdash;Does not set a fillMode `className`.
     *
     * @default `solid`
     */
    fillMode?: null | 'solid' | 'flat' | 'outline';
    /**
     * The `onChange` callback of the `input` element inside the TextBox.
     */
    onChange?: (event: TextBoxChangeEvent) => void;
    /**
     * Indicates if the component is in `valid` state
     */
    valid?: boolean;
    /**
     * Sets a custom prefix to the TextBox component.
     */
    prefix?: CustomComponent<any>;
    /**
     * Sets a custom suffix to the TextBox component.
     */
    suffix?: CustomComponent<any>;
    /**
     * Represents the `autoFocus` HTML attribute that will be applied to the input element of the TextBox. (Defaults to `false`)
     */
    autoFocus?: boolean;
    /**
     * @hidden
     */
    unstyled?: InputsClassStructure;
    /**
     * Sets the HTML attributes of the inner focusable input element.
     * Attributes which are essential for certain component functionalities cannot be changed.
     */
    inputAttributes?: React_2.InputHTMLAttributes<HTMLInputElement>;
}

/**
 * Specifies the size of a color cell.
 *
 * The possible values are:
 * * (Default) `number = 24`
 * * `{ width: number, height: number }`
 */
declare type TileSize = {
    width: number;
    height: number;
};

/**
 * The props passed to the Checkbox and Switch components.
 */
export declare interface ToggleBaseProps {
    value?: any;
    checked?: any;
    defaultChecked?: any;
}

/**
 * @hidden
 */
export declare const toRound: (num: number, base: number) => number;

export { }
